@@ -1,7 +1,6 @@
 import logging
 import sys
 
-from pyaedt import is_ironpython
 from pyaedt import log_handler
 from pyaedt import settings
 
@@ -124,13 +123,15 @@ class AedtLogger(object):
         self.level = level
         self.filename = filename or settings.logger_file_path
         settings.logger_file_path = self.filename
-        if is_ironpython:
-            logging.basicConfig()
+        # if is_ironpython:
+        #     logging.basicConfig()
         self._global = logging.getLogger("Global")
         self._file_handler = None
         self._std_out_handler = None
-        self.formatter = logging.Formatter(settings.logger_formatter, datefmt=settings.logger_datefmt)
-
+        if settings.formatter:
+            self.formatter = settings.formatter
+        else:
+            self.formatter = logging.Formatter(settings.logger_formatter, datefmt=settings.logger_datefmt)
         if not settings.enable_logger:
             self._global.addHandler(logging.NullHandler())
             return
