@@ -111,27 +111,16 @@ class Analysis(Design, object):
         self._setup = None
         if setup_name:
             self.analysis_setup = setup_name
-        self.solution_type = solution_type
         self._materials = Materials(self)
         self.logger.info("Materials Loaded")
         self._available_variations = self.AvailableVariations(self)
-        if "HFSS 3D Layout Design" in self.design_type:
-            self._oanalysis = self._odesign.GetModule("SolveSetups")
-        elif "EMIT" in self.design_type or "Maxwell Circuit" in self.design_type:
-            self._oanalysis = None
-        elif "Circuit Design" in self.design_type or "Twin Builder" in self.design_type:
-            self._oanalysis = self._odesign.GetModule("SimSetup")
-        else:
-            self._oanalysis = self._odesign.GetModule("AnalysisSetup")
 
         if self.design_type != "Maxwell Circuit":
-            self._ooptimetrics = self._odesign.GetModule("Optimetrics")
-            self._ooutput_variable = self._odesign.GetModule("OutputVariable")
             self.setups = [self.get_setup(setup_name) for setup_name in self.setup_names]
 
         self.parametrics = ParametricSetups(self)
         self.optimizations = OptimizationSetups(self)
-        self.native_components = self._get_native_data()
+        self._native_components = []
         self.SOLUTIONS = SOLUTIONS()
         self.SETUPS = SETUPS()
         self.AXIS = AXIS()
@@ -140,39 +129,16 @@ class Analysis(Design, object):
         self.GRAVITY = GRAVITY()
 
     @property
-    def ooptimetrics(self):
-        """AEDT Optimetrics Module.
+    def native_components(self):
+        """Native Component dictionary.
 
-        References
-        ----------
-
-        >>> oDesign.GetModule("Optimetrics")
+        Returns
+        -------
+        dict[str, :class:`pyaedt.modules.Boundaries.NativeComponentObject`]
         """
-        return self._ooptimetrics
-
-    @property
-    def ooutput_variable(self):
-        """AEDT Output Variable Module.
-
-        References
-        ----------
-
-        >>> oDesign.GetModule("OutputVariable")
-        """
-        return self._ooutput_variable
-
-    @property
-    def oanalysis(self):
-        """Analysis AEDT Module.
-
-        References
-        ----------
-
-        >>> oDesign.GetModule("SolveSetups")
-        >>> oDesign.GetModule("SimSetup")
-        >>> oDesign.GetModule("AnalysisSetup")
-        """
-        return self._oanalysis
+        if not self._native_components:
+            self._native_components = self._get_native_data()
+        return self._native_components
 
     @property
     def output_variables(self):
@@ -371,18 +337,19 @@ class Analysis(Design, object):
             sweep_list.reverse()
         else:
             for el in setup_list:
-                if self.solution_type == "HFSS3DLayout" or self.solution_type == "HFSS 3D Layout Design":
-                    sweeps = self.oanalysis.GelAllSolutionNames()
+                sweeps = []
+                setuptype = self.design_solutions.default_adaptive
+                if setuptype:
+                    sweep_list.append(el + " : " + setuptype)
                 else:
-                    setuptype = self.design_solutions.default_adaptive
-                    if setuptype:
-                        sweep_list.append(el + " : " + setuptype)
-                    else:
-                        sweep_list.append(el)
-                try:
-                    sweeps = list(self.oanalysis.GetSweeps(el))
-                except:
-                    sweeps = []
+                    sweep_list.append(el)
+                if self.design_type in ["HFSS 3D Layout Design"]:
+                    sweeps = self.oanalysis.GelAllSolutionNames()
+                elif self.solution_type not in ["Eigenmode"]:
+                    try:
+                        sweeps = list(self.oanalysis.GetSweeps(el))
+                    except:
+                        sweeps = []
                 for sw in sweeps:
                     if el + " : " + sw not in sweep_list:
                         sweep_list.append(el + " : " + sw)
@@ -546,14 +513,14 @@ class Analysis(Design, object):
         get_mutual_terms : bool, optional
             Whether to return mutual terms. The default is ``True``.
         first_element_filter : str, optional
-            Filter to apply to the first element of the equation. This parameter accepts ``*``
-            and ``?`` as special characters. The default is ``None``.
+            Filter to apply to the first element of the equation.
+            This parameter accepts ``*`` and ``?`` as special characters. The default is ``None``.
         second_element_filter : str, optional
-            Filter to apply to the second element of the equation. This parameter accepts ``*``
-            and ``?`` as special characters. The default is ``None``.
+            Filter to apply to the second element of the equation.
+            This parameter accepts ``*`` and ``?`` as special characters. The default is ``None``.
         category : str
-            Plot category name as in the report (including operator). The default is ``"dB(S"`,
-            which is the plot category name for capacitance.
+            Plot category name as in the report (including operator).
+            The default is ``"dB(S"``,  which is the plot category name for capacitance.
 
         Returns
         -------
@@ -811,6 +778,8 @@ class Analysis(Design, object):
 
         >>> oModule.ExportConvergence
         """
+        if " : " in setup_name:
+            setup_name = setup_name.split(" : ")[0]
         if not file_path:
             file_path = os.path.join(self.working_directory, generate_unique_name("Convergence") + ".prop")
         if not variation_string:
@@ -993,21 +962,14 @@ class Analysis(Design, object):
             >>> oDesign.GetVariableValue
             >>> oDesign.GetNominalVariation"""
             families = []
-            if self._app.design_type == "HFSS 3D Layout Design":
-                listvar = self._app.variable_manager._get_var_list_from_aedt(self._app._odesign)
-                for el in listvar:
-                    families.append(el + ":=")
-                    families.append([self._app._odesign.GetVariableValue(el)])
-            else:
-                variation = self._app._odesign.GetNominalVariation()
-                for el in self.variables:
-                    families.append(el + ":=")
-                    families.append([self._app._odesign.GetVariationVariableValue(variation, el)])
+            for k, v in list(self._app.variable_manager.independent_variables.items()):
+                families.append(k + ":=")
+                families.append([v.expression])
             return families
 
         @property
         def nominal_w_values_dict(self):
-            """Nominal with values in a dictionary.
+            """Nominal independent with values in a dictionary.
 
             References
             ----------
@@ -1017,19 +979,31 @@ class Analysis(Design, object):
             >>> oDesign.GetVariableValue
             >>> oDesign.GetNominalVariation"""
             families = {}
-            if self._app.design_type in ["HFSS 3D Layout Design", "Circuit Design", "Twin Builder"]:
-                listvar = self._app.variable_manager._get_var_list_from_aedt(self._app._odesign)
-                for el in listvar:
-                    families[el] = self._app._odesign.GetVariableValue(el)
-            else:
-                variation = self._app._odesign.GetNominalVariation()
-                for el in self.variables:
-                    families[el] = self._app._odesign.GetVariationVariableValue(variation, el)
+            for k, v in list(self._app.variable_manager.independent_variables.items()):
+                families[k] = v.expression
+
+            return families
+
+        @property
+        def nominal_w_values_dict_w_dependent(self):
+            """Nominal  with values in a dictionary.
+
+            References
+            ----------
+
+            >>> oDesign.GetChildObject('Variables').GetChildNames
+            >>> oDesign.GetVariables
+            >>> oDesign.GetVariableValue
+            >>> oDesign.GetNominalVariation"""
+            families = {}
+            for k, v in list(self._app.variable_manager.variables.items()):
+                families[k] = v.expression
+
             return families
 
         @property
         def all(self):
-            """All."""
+            """List of all independent variables with `["All"]` value."""
             families = []
             for el in self.variables:
                 families.append(el + ":=")
