@@ -24,7 +24,6 @@ from pyaedt.generic.constants import AEDT_UNITS
 from pyaedt.generic.constants import SI_UNITS
 from pyaedt.generic.constants import unit_system
 from pyaedt.generic.general_methods import is_number, is_array
-from pyaedt import is_ironpython
 
 
 class CSVDataset:
@@ -215,8 +214,8 @@ class CSVDataset:
         if self._index < (self.number_of_rows - 1):
             output = []
             for column in self._header:
-                string_value = str(self._data[column][self._index])
-                output.append(string_value)
+                evaluated_value = str(self._data[column][self._index])
+                output.append(evaluated_value)
             output_string = " ".join(output)
             self._index += 1
         else:
@@ -681,12 +680,12 @@ class VariableManager(object):
             for variable_name in listvar:
                 variable_expression = self.get_expression(variable_name)
                 all_names[variable_name] = variable_expression
-                # try:
                 si_value = self._app.get_evaluated_value(variable_name)
                 value = Variable(variable_expression, None, si_value, all_names, name=variable_name, app=self._app)
-                if independent and (is_array(value._calculated_value) or is_number(value._calculated_value)):
+                is_number_flag = is_number(value._calculated_value)
+                if independent and is_number_flag:
                     var_dict[variable_name] = value
-                elif dependent and not is_array(value._calculated_value) and not is_number(value._calculated_value):
+                elif dependent and not is_number_flag:
                     var_dict[variable_name] = value
         return var_dict
 
@@ -823,7 +822,7 @@ class VariableManager(object):
             variable = expression
         elif isinstance(expression, Variable):
             # Handle input type variable
-            variable = expression.string_value
+            variable = expression.evaluated_value
         elif is_number(expression):
             # Handle input type int/float, etc (including numeric 0)
             variable = str(expression)
@@ -1079,6 +1078,7 @@ class Variable(object):
         self._postprocessing = postprocessing
         self._circuit_parameter = circuit_parameter
         self._description = description
+        self._is_optimization_included = None
         if units:
             if unit_system(units):
                 specified_units = units
@@ -1142,16 +1142,220 @@ class Variable(object):
             if self._app:
                 self._app.logger.error('"Failed to update property "name".')
 
+    @property
+    def is_optimization_enabled(self):
+        """ "Check if optimization is enabled."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Optimization/Included")
+        return
+
+    @is_optimization_enabled.setter
+    def is_optimization_enabled(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Optimization/Included", value)
+
+    @property
+    def optimization_min_value(self):
+        """ "Optimization min value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Optimization/Min")
+        return
+
+    @optimization_min_value.setter
+    def optimization_min_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Optimization/Min", value)
+
+    @property
+    def optimization_max_value(self):
+        """ "Optimization max value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Optimization/Max")
+        return
+
+    @optimization_max_value.setter
+    def optimization_max_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Optimization/Max", value)
+
+    @property
+    def is_sensitivity_enabled(self):
+        """Check if Sensitivity is enabled."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/Included")
+        return
+
+    @is_sensitivity_enabled.setter
+    def is_sensitivity_enabled(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/Included", value)
+
+    @property
+    def sensitivity_min_value(self):
+        """ "Sensitivity min value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/Min")
+        return
+
+    @sensitivity_min_value.setter
+    def sensitivity_min_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/Min", value)
+
+    @property
+    def sensitivity_max_value(self):
+        """ "Sensitivity max value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/Max")
+        return
+
+    @sensitivity_max_value.setter
+    def sensitivity_max_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/Max", value)
+
+    @property
+    def sensitivity_initial_disp(self):
+        """ "Sensitivity initial value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Sensitivity/IDisp")
+        return
+
+    @sensitivity_initial_disp.setter
+    def sensitivity_initial_disp(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Sensitivity/IDisp", value)
+
+    @property
+    def is_tuning_enabled(self):
+        """Check if tuning is enabled."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Included")
+        return
+
+    @is_tuning_enabled.setter
+    def is_tuning_enabled(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Included", value)
+
+    @property
+    def tuning_min_value(self):
+        """ "Tuning min value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Min")
+        return
+
+    @tuning_min_value.setter
+    def tuning_min_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Min", value)
+
+    @property
+    def tuning_max_value(self):
+        """ "Tuning max value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Max")
+        return
+
+    @tuning_max_value.setter
+    def tuning_max_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Max", value)
+
+    @property
+    def tuning_step_value(self):
+        """ "Tuning Step value."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Tuning/Step")
+        return
+
+    @tuning_step_value.setter
+    def tuning_step_value(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Tuning/Step", value)
+
+    @property
+    def is_statistical_enabled(self):
+        """Check if statistical is enabled."""
+
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                return oo.GetChildObject(self._variable_name).GetPropValue("Statistical/Included")
+        return
+
+    @is_statistical_enabled.setter
+    def is_statistical_enabled(self, value):
+        if self._app:
+            oo = self._app.get_oo_object(self._aedt_obj, "Variables")
+            if oo:
+                oo.GetChildObject(self._variable_name).SetPropValue("Statistical/Included", value)
+
     @property
     def read_only(self):
         """Read-only flag value."""
         if self._app:
             try:
-                if not is_ironpython:
-                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_ReadOnly
-                else:  # pragma: no cover
-                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_ReadOnly()
-
+                return (
+                    self._aedt_obj.GetChildObject("Variables")
+                    .GetChildObject(self._variable_name)
+                    .GetPropValue("ReadOnly")
+                )
             except:
                 return self._readonly
         return self._readonly
@@ -1170,10 +1374,11 @@ class Variable(object):
         """Hidden flag value."""
         if self._app:
             try:
-                if not is_ironpython:
-                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Hidden
-                else:  # pragma: no cover
-                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Hidden()
+                return (
+                    self._aedt_obj.GetChildObject("Variables")
+                    .GetChildObject(self._variable_name)
+                    .GetPropValue("Hidden")
+                )
             except:
                 return self._hidden
         return self._hidden
@@ -1192,14 +1397,11 @@ class Variable(object):
         """Description value."""
         if self._app:
             try:
-                if not is_ironpython:
-                    return (
-                        self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Description
-                    )
-                else:  # pragma: no cover
-                    return (
-                        self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Description()
-                    )
+                return (
+                    self._aedt_obj.GetChildObject("Variables")
+                    .GetChildObject(self._variable_name)
+                    .GetPropValue("Description")
+                )
             except:
                 return self._description
         return self._description
@@ -1289,7 +1491,7 @@ class Variable(object):
         return self._value
 
     @property
-    def string_value(self):
+    def evaluated_value(self):
         """String value.
 
         The numeric value with the unit is concatenated and returned as a string. The numeric display
