@@ -21,7 +21,9 @@ try:
     from System.Collections.Generic import List
 except ImportError:  # pragma: no cover
     if os.name != "posix":
-        warnings.warn("Python.NET is needed to run PyAEDT.")
+        warnings.warn("PythonNET is needed to run PyAEDT.")
+    elif sys.version[0] == 3 and sys.version[1] < 7:
+        warnings.warn("EDB requires Linux Python 3.7 or later.")
 from pyaedt import settings
 from pyaedt.edb_core import Components, EdbNets, EdbPadstacks, EdbLayout, EdbHfss, EdbSiwave, EdbStackup
 from pyaedt.edb_core.EDB_Data import EdbBuilder, SimulationConfiguration
@@ -35,6 +37,7 @@ from pyaedt.generic.general_methods import (
     is_ironpython,
     inside_desktop,
 )
+from pyaedt.misc.misc import list_installed_ansysem
 from pyaedt.aedt_logger import AedtLogger
 from pyaedt.generic.process import SiwaveSolve
 from pyaedt.edb_core.general import convert_py_list_to_net_list
@@ -51,7 +54,7 @@ try:
 except ImportError:
     if os.name != "posix":
         warnings.warn(
-            "The clr is missing. Install Python.NET or use an IronPython version if you want to use the EDB module."
+            "The clr is missing. Install PythonNET or use an IronPython version if you want to use the EDB module."
         )
         edb_initialized = False
 
@@ -106,7 +109,7 @@ class Edb(object):
         edbpath=None,
         cellname=None,
         isreadonly=False,
-        edbversion="2021.2",
+        edbversion=None,
         isaedtowned=False,
         oproject=None,
         student_version=False,
@@ -139,6 +142,12 @@ class Edb(object):
 
             self.student_version = student_version
             self.logger.info("Logger is initialized in EDB.")
+            if not edbversion:
+                try:
+                    edbversion = "20{}.{}".format(list_installed_ansysem()[0][-3:-1], list_installed_ansysem()[0][-1:])
+                    self._logger.info("Edb version " + edbversion)
+                except IndexError:
+                    raise Exception("No ANSYSEM_ROOTxxx is found.")
             self.edbversion = edbversion
             self.isaedtowned = isaedtowned
             self._init_dlls()
@@ -233,8 +242,7 @@ class Edb(object):
         """Cell name container.
         Returns
         -------
-        list of str
-            List of cell names.
+        list of str, cell names.
         """
         names = []
         for cell in list(self._db.TopCircuitCells):
@@ -261,11 +269,16 @@ class Edb(object):
                         self.base_path = edb_path
                         sys.path.append(edb_path)
                         os.environ[env_value(self.edbversion)] = self.base_path
-
-            clr.AddReferenceToFile("Ansys.Ansoft.Edb.dll")
-            clr.AddReferenceToFile("Ansys.Ansoft.EdbBuilderUtils.dll")
-            clr.AddReferenceToFile("EdbLib.dll")
-            clr.AddReferenceToFileAndPath(os.path.join(self.base_path, "Ansys.Ansoft.SimSetupData.dll"))
+            if is_ironpython:
+                clr.AddReferenceToFile("Ansys.Ansoft.Edb.dll")
+                clr.AddReferenceToFile("Ansys.Ansoft.EdbBuilderUtils.dll")
+                clr.AddReferenceToFile("EdbLib.dll")
+                clr.AddReferenceToFileAndPath(os.path.join(self.base_path, "Ansys.Ansoft.SimSetupData.dll"))
+            else:
+                clr.AddReference("Ansys.Ansoft.Edb")
+                clr.AddReference("Ansys.Ansoft.EdbBuilderUtils")
+                clr.AddReference("EdbLib")
+                clr.AddReference("Ansys.Ansoft.SimSetupData")
         else:
             if self.student_version:
                 self.base_path = env_path_student(self.edbversion)
@@ -292,7 +305,7 @@ class Edb(object):
     def edblib(self):
         """EdbLib object containing advanced EDB methods not accessible directly from Python."""
         if not self._edblib:
-            if os.name == "posix":
+            if os.name == "posix" and is_ironpython:
                 clr.AddReferenceToFile("EdbLib.dll")
                 clr.AddReferenceToFile("DataModel.dll")
             else:
@@ -444,12 +457,13 @@ class Edb(object):
     def import_layout_pcb(
         self, input_file, working_dir, init_dlls=False, anstranslator_full_path="", use_ppe=False, control_file=None
     ):
-        """Import a BRD file and generate an ``edb.def`` file in the working directory.
+        """Import a board file and generate an ``edb.def`` file in the working directory.
+        It supports all AEDT Formats (dxf, gds, xml (ipc2581), brd, tgz....).
 
         Parameters
         ----------
         input_file : str
-            Full path to the BRD file.
+            Full path to the board file.
         working_dir : str
             Directory in which to create the ``aedb`` folder. The AEDB file name will be the
             same as the BRD file name.
@@ -460,13 +474,12 @@ class Edb(object):
         use_ppe : bool
             Whether to use or not PPE License. The default is ``False``.
         control_file : str, optional
-            Path to xml file. If None, the tool will try to get it from the same path/name of the gds.
+            Path to xml file. If None, the tool will try to get it from the same path/name of the gds/dxf.
 
         Returns
         -------
         str
             Full path to the AEDB file.
-
         """
         self._components = None
         self._core_primitives = None
@@ -488,18 +501,26 @@ class Edb(object):
         if not working_dir:
             working_dir = os.path.dirname(input_file)
         if os.name == "posix":
-            cmd_translator = "{} {} {}".format(command, input_file, os.path.join(working_dir, aedb_name))
-            cmd_translator += " -l={}".format(os.path.join(working_dir, "Translator.log"))
+            cmd_translator = [
+                command,
+                input_file,
+                os.path.join(working_dir, aedb_name),
+                "-l={}".format(os.path.join(working_dir, "Translator.log")),
+            ]
         else:
-            cmd_translator = '"{}" "{}" "{}"'.format(command, input_file, os.path.join(working_dir, aedb_name))
-            cmd_translator += ' -l="{}"'.format(os.path.join(working_dir, "Translator.log"))
+            cmd_translator = [
+                command,
+                input_file,
+                os.path.join(working_dir, aedb_name),
+                '-l="{}"'.format(os.path.join(working_dir, "Translator.log")),
+            ]
         if not use_ppe:
-            cmd_translator += " -ppe=false"
-        if control_file and input_file[-3:] == "gds":
+            cmd_translator.append("-ppe=false")
+        if control_file and input_file[-3:] not in ["brd"]:
             if os.name == "posix":
-                cmd_translator += " -c={}".format(control_file)
+                cmd_translator.append("-c={}".format(control_file))
             else:
-                cmd_translator += ' -c="{}"'.format(control_file)
+                cmd_translator.append('-c="{}"'.format(control_file))
         p = subprocess.Popen(cmd_translator)
         p.wait()
         if not os.path.exists(os.path.join(working_dir, aedb_name)):
@@ -1030,6 +1051,47 @@ class Edb(object):
             self._init_objects()
         return True
 
+    @pyaedt_function_handler()
+    def get_conformal_polygon_from_netlist(self, netlist=None):
+        """Return an EDB conformal polygon based on net list.
+
+        Parameters
+        ----------
+
+        netlist : List of net name.
+            list[str]
+
+        Returns
+        -------
+
+        Edb polygon object
+            Edb.Cell.Primitive.Polygon object
+
+        """
+        shutil.copytree(self.edbpath, os.path.join(self.edbpath, "_temp_aedb"))
+        temp_edb = Edb(os.path.join(self.edbpath, "_temp_aedb"))
+        for via in list(temp_edb.core_padstack.padstack_instances.values()):
+            via.pin.Delete()
+        if netlist:
+            nets = convert_py_list_to_net_list(
+                [net for net in list(self.active_layout.Nets) if net.GetName() in netlist]
+            )
+            _poly = temp_edb.active_layout.GetExpandedExtentFromNets(
+                nets, self.edb.Geometry.ExtentType.Conforming, 0.0, True, True, 1
+            )
+        else:
+            nets = convert_py_list_to_net_list(
+                [net for net in list(temp_edb.active_layout.Nets) if "gnd" in net.GetName().lower()]
+            )
+            _poly = temp_edb.active_layout.GetExpandedExtentFromNets(
+                nets, self.edb.Geometry.ExtentType.Conforming, 0.0, True, True, 1
+            )
+            temp_edb.close_edb()
+        if _poly:
+            return _poly
+        else:
+            return False
+
     @pyaedt_function_handler()
     def arg_with_dim(self, Value, sUnits):
         """Format arguments with dimensions.
@@ -1594,7 +1656,7 @@ class Edb(object):
                 old_cell_name = self.active_cell.GetName()
                 if self.create_cutout(simulation_setup=simulation_setup, output_aedb_path=simulation_setup.output_aedb):
                     self.logger.info("Cutout processed.")
-                    old_cell = self.active_cell.FindByName(self._db, 0, old_cell_name)
+                    old_cell = self.active_cell.FindByName(self._db, self.edb.Cell.CellType.CircuitCell, old_cell_name)
                     if old_cell:
                         old_cell.Delete()
                 else:  # pragma: no cover
@@ -1602,8 +1664,8 @@ class Edb(object):
             self.logger.info("Deleting existing ports.")
             map(lambda port: port.Delete(), list(self.active_layout.Terminals))
             map(lambda pg: pg.Delete(), list(self.active_layout.PinGroups))
-            self.logger.info("Creating ports for signal nets.")
             if simulation_setup.solver_type == SolverType.Hfss3dLayout:
+                self.logger.info("Creating HFSS ports for signal nets.")
                 for cmp in simulation_setup.components:
                     self.core_components.create_port_on_component(
                         cmp,
@@ -1626,7 +1688,7 @@ class Edb(object):
                 self.core_hfss.configure_hfss_extents(simulation_setup)
                 if not self.core_hfss.configure_hfss_analysis_setup(simulation_setup):
                     self.logger.error("Failed to configure HFSS simulation setup.")
-            if simulation_setup.solver_type == SolverType.Siwave:
+            if simulation_setup.solver_type == SolverType.SiwaveSYZ:
                 for cmp in simulation_setup.components:
                     self.core_components.create_port_on_component(
                         cmp,
@@ -1639,8 +1701,20 @@ class Edb(object):
                 if not self.core_siwave.configure_siw_analysis_setup(simulation_setup):  # pragma: no cover
                     self.logger.error("Failed to configure Siwave simulation setup.")
 
-            # if simulation_setup.defeature_layout:
-            #    self.core_hfss.layout_defeaturing(simulation_setup)
+            if simulation_setup.solver_type == SolverType.SiwaveDC:
+                self.core_components.create_source_on_component(simulation_setup.sources)
+                if not self.core_siwave.configure_siw_analysis_setup(simulation_setup):  # pragma: no cover
+                    self.logger.error("Failed to configure Siwave simulation setup.")
             return True
         except:  # pragma: no cover
             return False
+
+    @pyaedt_function_handler()
+    def get_statistics(self, compute_area=False):
+        """Return the EDBStatistics object.
+
+        Returns
+        -------
+        The EDBStatistics object from the loaded layout.
+        """
+        return self.core_primitives.get_layout_statistics(evaluate_area=compute_area, net_list=None)
