@@ -451,14 +451,11 @@ class EdbHfss(object):
             for pin in self._pedb.core_components.components[ref].pins.items():
                 if pin[1].net_name in net_list and pin[1].pin.IsLayoutPin():
                     port_name = "{}_{}_{}".format(ref, pin[1].net_name, pin[1].pin.GetName())
-                    if is_ironpython:
-                        (
-                            res,
-                            from_layer_pos,
-                            to_layer_pos,
-                        ) = pin[1].pin.GetLayerRange()
-                    else:
-                        res, from_layer_pos, to_layer_pos = pin[1].pin.GetLayerRange(None, None)
+                    (
+                        res,
+                        from_layer_pos,
+                        to_layer_pos,
+                    ) = pin[1].pin.GetLayerRange()
                     if (
                         res
                         and from_layer_pos
@@ -490,10 +487,8 @@ class EdbHfss(object):
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        if is_ironpython:
-            res, fromLayer_pos, toLayer_pos = pinpos.GetLayerRange()
-        else:
-            res, fromLayer_pos, toLayer_pos = pinpos.GetLayerRange(None, None)
+        res, fromLayer_pos, toLayer_pos = pinpos.GetLayerRange()
+
         if not portname:
             portname = generate_unique_name("Port_" + pinpos.GetNet().GetName())
         edbpointTerm_pos = self._edb.Cell.Terminal.PadstackInstanceTerminal.Create(
@@ -505,16 +500,120 @@ class EdbHfss(object):
             return False
 
     @pyaedt_function_handler()
-    def create_lumped_port_on_trace(
+    def create_edge_port_on_polygon(
+        self,
+        polygon=None,
+        reference_polygon=None,
+        terminal_point=None,
+        reference_point=None,
+        reference_layer=None,
+        port_name=None,
+        port_impedance=50.0,
+        force_circuit_port=False,
+    ):
+        """Create lumped port between two edges from two different polygons. Can also create a vertical port when
+        the reference layer name is only provided. When a port is created between two edge from two polygons which don't
+        belong to the same layer, a circuit port will be automatically created instead of lumped. To enforce the circuit
+        port instead of lumped,use the boolean force_circuit_port.
+
+        Parameters
+        ----------
+        polygon : The EDB polygon object used to assign the port.
+            Edb.Cell.Primitive.Polygon object.
+
+        reference_polygon : The EDB polygon object used to define the port reference.
+            Edb.Cell.Primitive.Polygon object.
+
+        terminal_point : The coordinate of the point to define the edge terminal of the port. This point must be
+        located on the edge of the polygon where the port has to be placed. For instance taking the middle point
+        of an edge is a good practice but any point of the edge should be valid. Taking a corner might cause unwanted
+        port location.
+            list[float, float] with values provided in meter.
+
+        reference_point : same as terminal_point but used for defining the reference location on the edge.
+            list[float, float] with values provided in meter.
+
+        reference_layer : Name used to define port reference for vertical ports.
+            str the layer name.
+
+        port_name : Name of the port.
+            str.
+
+        port_impedance : port impedance value. Default value is 50 Ohms.
+            float, impedance value.
+
+        force_circuit_port ; used to force circuit port creation instead of lumped. Works for vertical and coplanar
+        ports.
+
+        Example
+        --------
+
+        >>> edb_path = path_to_edb
+        >>> edb = Edb(edb_path)
+        >>> poly_list = [poly for poly in list(edb.active_layout.Primitives) if poly.GetPrimitiveType() == 2]
+        >>> port_poly = [poly for poly in poly_list if poly.GetId() == 17][0]
+        >>> ref_poly = [poly for poly in poly_list if poly.GetId() == 19][0]
+        >>> port_location = [-65e-3, -13e-3]
+        >>> ref_location = [-63e-3, -13e-3]
+        >>> edb.core_hfss.create_edge_port_on_polygon(polygon=port_poly, reference_polygon=ref_poly,
+        >>> terminal_point=port_location, reference_point=ref_location)
+
+        """
+        if not polygon:
+            self._logger.error("No polygon provided for port {} creation".format(port_name))
+            return False
+        if reference_layer:
+            reference_layer = self._pedb.core_stackup.signal_layers[reference_layer]._layer
+            if not reference_layer:
+                self._logger.error("Specified layer for port {} creation was not found".format(port_name))
+        if not isinstance(terminal_point, list):
+            self._logger.error("Terminal point must be a list of float with providing the point location in meter")
+            return False
+        terminal_point = self._edb.Geometry.PointData(
+            self._get_edb_value(terminal_point[0]), self._get_edb_value(terminal_point[1])
+        )
+        if reference_point and isinstance(reference_point, list):
+            reference_point = self._edb.Geometry.PointData(
+                self._get_edb_value(reference_point[0]), self._get_edb_value(reference_point[1])
+            )
+        if not port_name:
+            port_name = generate_unique_name("Port_")
+        edge = self._edb.Cell.Terminal.PrimitiveEdge.Create(polygon, terminal_point)
+        edges = convert_py_list_to_net_list(edge, self._edb.Cell.Terminal.Edge)
+        edge_term = self._edb.Cell.Terminal.EdgeTerminal.Create(
+            polygon.GetLayout(), polygon.GetNet(), port_name, edges, isRef=False
+        )
+        if force_circuit_port:
+            edge_term.SetIsCircuitPort(True)
+        if port_impedance:
+            edge_term.SetImpedance(self._pedb.edb_value(port_impedance))
+        edge_term.SetName(port_name)
+        if reference_polygon and reference_point:
+            ref_edge = self._edb.Cell.Terminal.PrimitiveEdge.Create(reference_polygon, reference_point)
+            ref_edges = convert_py_list_to_net_list(ref_edge, self._edb.Cell.Terminal.Edge)
+            ref_edge_term = self._edb.Cell.Terminal.EdgeTerminal.Create(
+                reference_polygon.GetLayout(), reference_polygon.GetNet(), port_name + "_ref", ref_edges, isRef=True
+            )
+            if reference_layer:
+                ref_edge_term.SetReferenceLayer(reference_layer)
+            if force_circuit_port:
+                ref_edge_term.SetIsCircuitPort(True)
+            if port_impedance:
+                ref_edge_term.SetImpedance(self._pedb.edb_value(port_impedance))
+            edge_term.SetReferenceTerminal(ref_edge_term)
+        return True
+
+    @pyaedt_function_handler()
+    def create_lumped_port_on_net(
         self,
         nets=None,
         reference_layer=None,
         return_points_only=False,
-        polygon_trace_threshhold=300e-6,
         digit_resolution=6,
-        point_list=None,
     ):
-        """Create an edge port on traces.
+        """Create an edge port on nets. Only ports on traces (e.g. Path) are currently supported.
+        The command will look for traces on the nets and will try to assign vertical lumped port on first and last
+        point from the trace. To be used with cautious.
 
         Parameters
         ----------
@@ -528,20 +627,9 @@ class EdbHfss(object):
             Use this boolean when you want to return only the points from the edges and not creating ports. Default
             value is ``False``.
 
-        polygon_trace_threshhold : float, optional
-            Used only when selected nets are routed as polygon. The value gives the algorithm the threshold
-            of the polygon width at the design border for considering placing an edge port. The default value is
-            ``300-e6``.
-
         digit_resolution : int, optional
             The number of digits carried for the edge location accuracy. The default value is ``6``.
 
-        point_list : list(tuples), optional
-            The list of points where to define ports. The port evaluation is done for each net provided and if a point
-            belongs to a center line points from a path or a polygon then the port will be created. If the point is not
-            found the ports  will be skipped. If point_list is None, the algorithm will try to find the edges from
-            traces or polygons touching the layout bounding box.
-
         Returns
         -------
         bool
@@ -560,11 +648,8 @@ class EdbHfss(object):
                 elif isinstance(nn, self._edb.Cell.Net):
                     temp_nets.append(nn)
             nets = temp_nets
-        if point_list:
-            if isinstance(point_list, tuple):
-                point_list = [point_list]
-        edges_pts = []
         if nets:
+            edges_pts = []
             if isinstance(reference_layer, str):
                 try:
                     reference_layer = self._pedb.core_stackup.signal_layers[reference_layer]._layer
@@ -579,134 +664,23 @@ class EdbHfss(object):
                 net_paths = [
                     pp for pp in net_primitives if pp.GetPrimitiveType() == self._edb.Cell.Primitive.PrimitiveType.Path
                 ]
-                net_poly = [
-                    pp
-                    for pp in net_primitives
-                    if pp.GetPrimitiveType() == self._edb.Cell.Primitive.PrimitiveType.Polygon
-                ]
                 for path in net_paths:
                     trace_path_pts = list(path.GetCenterLine().Points)
                     port_name = "{}_{}".format(net.GetName(), path.GetId())
-                    if point_list:
-                        for _pt in point_list:
-                            if isinstance(_pt, tuple):
-                                found_pt = [
-                                    p
-                                    for p in trace_path_pts
-                                    if round(p.X.ToDouble(), 6) == round(_pt[0], 6)
-                                    and round(p.Y.ToDouble(), 6) == round(_pt[1], 6)
-                                ]
-                                if found_pt:
-                                    pt = self._edb.Geometry.PointData(
-                                        self._get_edb_value(_pt[0]),
-                                        self._get_edb_value(_pt[1]),
-                                    )
-                                    if not self._hfss_terminals.CreateEdgePort(path, pt, reference_layer, port_name):
-                                        raise Exception(
-                                            "edge port creation failed on point {}, {}".format(
-                                                str(pt.X.ToDouble()),
-                                                str(pt.Y.ToDouble()),
-                                            )
-                                        )
-                    else:
-                        for pt in trace_path_pts:
-                            _pt = [
-                                round(pt.X.ToDouble(), digit_resolution),
-                                round(pt.Y.ToDouble(), digit_resolution),
-                            ]
-                            if bool(set(_pt) & set(layout_bbox)):
-                                if return_points_only:
-                                    edges_pts.append(_pt)
-                                else:
-                                    if not self._hfss_terminals.CreateEdgePort(
-                                        path, pt, reference_layer, port_name
-                                    ):  # pragma: no cover
-                                        raise Exception(
-                                            "edge port creation failed on point {}, {}".format(str(pt[0]), str(_pt[1]))
-                                        )
-                for poly in net_poly:
-                    pt_list = list(poly.GetPolygonData().Points)
-                    points_at_border = [
-                        pt
-                        for pt in pt_list
-                        if round(pt.X.ToDouble(), digit_resolution) in layout_bbox
-                        or round(pt.Y.ToDouble(), digit_resolution) in layout_bbox
-                    ]
-                    pt_at_left = [
-                        pt for pt in points_at_border if round(pt.X.ToDouble(), digit_resolution) == layout_bbox[0]
-                    ]
-                    pt_at_left_values = [pt.Y.ToDouble() for pt in pt_at_left]
-                    if pt_at_left_values:
-                        left_edge_length = abs(max(pt_at_left_values) - min(pt_at_left_values))
-                        if polygon_trace_threshhold >= left_edge_length > 0:
-                            if return_points_only:
-                                edges_pts.append(pt_at_left)
-                            else:
-                                port_name = generate_unique_name("port")
-                                if not self._hfss_terminals.CreateEdgePortOnPolygon(
-                                    poly,
-                                    convert_py_list_to_net_list(pt_at_left),
-                                    reference_layer,
-                                    port_name,
-                                ):  # pragma: no cover
-                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
-
-                    pt_at_bottom = [
-                        pt for pt in points_at_border if round(pt.Y.ToDouble(), digit_resolution) == layout_bbox[1]
-                    ]
-                    pt_at_bottom_values = [pt.X.ToDouble() for pt in pt_at_bottom]
-                    if pt_at_bottom_values:
-                        bot_edge_length = abs(max(pt_at_bottom_values) - min(pt_at_bottom_values))
-                        if polygon_trace_threshhold >= bot_edge_length > 0:
-                            if return_points_only:
-                                edges_pts.append(pt_at_bottom)
-                            else:
-                                port_name = generate_unique_name("port")
-                                if not self._hfss_terminals.CreateEdgePortOnPolygon(
-                                    poly,
-                                    convert_py_list_to_net_list(pt_at_bottom),
-                                    reference_layer,
-                                    port_name,
-                                ):  # pragma: no cover
-                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
-
-                    pt_at_right = [
-                        pt for pt in points_at_border if round(pt.X.ToDouble(), digit_resolution) == layout_bbox[2]
-                    ]
-                    pt_at_right_values = [pt.Y.ToDouble() for pt in pt_at_right]
-                    if pt_at_right_values:
-                        right_edge_length = abs(max(pt_at_right_values) - min(pt_at_right_values))
-                        if polygon_trace_threshhold >= right_edge_length > 0:
-                            if return_points_only:
-                                edges_pts.append(pt_at_right)
-                            else:
-                                port_name = generate_unique_name("port")
-                                if not self._hfss_terminals.CreateEdgePortOnPolygon(
-                                    poly,
-                                    convert_py_list_to_net_list(pt_at_right),
-                                    reference_layer,
-                                    port_name,
-                                ):  # pragma: no cover
-                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
-
-                    pt_at_top = [
-                        pt for pt in points_at_border if round(pt.Y.ToDouble(), digit_resolution) == layout_bbox[3]
-                    ]
-                    pt_at_top_values = [pt.X.ToDouble() for pt in pt_at_top]
-                    if pt_at_top_values:
-                        top_edge_length = abs(max(pt_at_top_values) - min(pt_at_top_values))
-                        if polygon_trace_threshhold >= top_edge_length > 0:
-                            if return_points_only:
-                                edges_pts.append(pt - pt_at_top)
-                            else:
-                                port_name = generate_unique_name("port")
-                                if not self._hfss_terminals.CreateEdgePortOnPolygon(
-                                    poly,
-                                    convert_py_list_to_net_list(pt_at_top),
-                                    reference_layer,
-                                    port_name,
-                                ):  # pragma: no cover
-                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
+                    for pt in trace_path_pts:
+                        _pt = [
+                            round(pt.X.ToDouble(), digit_resolution),
+                            round(pt.Y.ToDouble(), digit_resolution),
+                        ]
+                        if return_points_only:
+                            edges_pts.append(_pt)
+                        else:
+                            if not self._hfss_terminals.CreateEdgePort(
+                                path, pt, reference_layer, port_name
+                            ):  # pragma: no cover
+                                raise Exception(
+                                    "edge port creation failed on point {}, {}".format(str(pt[0]), str(_pt[1]))
+                                )
             if return_points_only:
                 return edges_pts
         return True
@@ -889,7 +863,8 @@ class EdbHfss(object):
         hfss_extent.HonorUserDielectric = simulation_setup.honor_user_dielectric
         hfss_extent.TruncateAirBoxAtGround = simulation_setup.truncate_airbox_at_ground
         hfss_extent.UseOpenRegion = simulation_setup.use_radiation_boundary
-        return self._active_layout.GetCell().SetHFSSExtentInfo(hfss_extent)
+        self._active_layout.GetCell().SetHFSSExtentInfo(hfss_extent)  # returns void
+        return True
 
     @pyaedt_function_handler()
     def configure_hfss_analysis_setup(self, simulation_setup=None):
@@ -952,10 +927,8 @@ class EdbHfss(object):
             # sweep.EnforceCausality = False
             sweep.EnforcePassivity = simulation_setup.enforce_passivity
             sweep.PassivityTolerance = simulation_setup.passivity_tolerance
-            if is_ironpython:
-                sweep.Frequencies.Clear()
-            else:
-                list(sweep.Frequencies).clear()
+            sweep.Frequencies.Clear()
+
             if simulation_setup.sweep_type == SweepType.LogCount:  # setup_info.SweepType == 'DecadeCount'
                 self._setup_decade_count_sweep(
                     sweep,
@@ -965,24 +938,14 @@ class EdbHfss(object):
                 )  # Added DecadeCount as a new attribute
 
             else:
-                if is_ironpython:
-                    sweep.Frequencies = self._pedb.simsetupdata.SweepData.SetFrequencies(
-                        simulation_setup.start_frequency,
-                        simulation_setup.stop_freq,
-                        simulation_setup.step_freq,
-                    )
-                else:
-                    sweep.Frequencies = convert_py_list_to_net_list(
-                        self._pedb.simsetupdata.SweepData.SetFrequencies(
-                            simulation_setup.start_frequency,
-                            simulation_setup.stop_freq,
-                            simulation_setup.step_freq,
-                        )
-                    )
-            if is_ironpython:
-                simsetup_info.SweepDataList.Add(sweep)
-            else:
-                simsetup_info.SweepDataList = convert_py_list_to_net_list([sweep])
+                sweep.Frequencies = self._pedb.simsetupdata.SweepData.SetFrequencies(
+                    simulation_setup.start_frequency,
+                    simulation_setup.stop_freq,
+                    simulation_setup.step_freq,
+                )
+
+            simsetup_info.SweepDataList.Add(sweep)
+
         except Exception as err:
             self._logger.error("Exception in Sweep configuration: {0}".format(err))
 
