@@ -60,11 +60,6 @@ class EdbNets(object):
         """Edb logger."""
         return self._pedb.logger
 
-    @property
-    def _nets_methods(self):
-        """ """
-        return self._pedb.edblib.Layout.NetsMethods
-
     @property
     def nets(self):
         """Nets.
@@ -598,7 +593,7 @@ class EdbNets(object):
         return nets_deleted
 
     @pyaedt_function_handler()
-    def find_or_create_net(self, net_name=""):
+    def find_or_create_net(self, net_name="", start_with="", contain="", end_with=""):
         """Find or create the net with the given name in the layout.
 
         Parameters
@@ -606,19 +601,71 @@ class EdbNets(object):
         net_name : str, optional
             Name of the net to find or create. The default is ``""``.
 
+        start_with : str, optional
+            All net name starting with the string. Not case-sensitive.
+
+        contain : str, optional
+            All net name containing the string. Not case-sensitive.
+
+        end_with : str, optional
+            All net name ending with the string. Not case-sensitive.
+
         Returns
         -------
         object
             Net Object
         """
-        if not net_name:
+        if not net_name and not start_with and not contain and not end_with:
             net_name = generate_unique_name("NET_")
             net = self._edb.Cell.Net.Create(self._active_layout, net_name)
+            return net
         else:
-            net = self._edb.Cell.Net.FindByName(self._active_layout, net_name)
-            if net.IsNull():
-                net = self._edb.Cell.Net.Create(self._active_layout, net_name)
-        return net
+            if not start_with and not contain and not end_with:
+                net = self._edb.Cell.Net.FindByName(self._active_layout, net_name)
+                if net.IsNull():
+                    net = self._edb.Cell.Net.Create(self._active_layout, net_name)
+                return net
+            elif start_with:
+                nets_found = [
+                    self.nets[net].net_object for net in list(self.nets.keys()) if net.lower().startswith(start_with)
+                ]
+                return nets_found
+            elif start_with and end_with:
+                nets_found = [
+                    self.nets[net].net_object
+                    for net in list(self.nets.keys())
+                    if net.lower().startswith(start_with) and net.lower().endswith(end_with)
+                ]
+                return nets_found
+            elif start_with and contain and end_with:
+                nets_found = [
+                    self.nets[net].net_object
+                    for net in list(self.nets.keys())
+                    if net.lower().startswith(start_with) and net.lower().endswith(end_with) and contain in net.lower()
+                ]
+                return nets_found
+            elif start_with and contain:
+                nets_found = [
+                    self.nets[net].net_object
+                    for net in list(self.nets.keys())
+                    if net.lower().startswith(start_with) and contain in net.lower()
+                ]
+                return nets_found
+            elif contain and end_with:
+                nets_found = [
+                    self.nets[net].net_object
+                    for net in list(self.nets.keys())
+                    if net.lower().endswith(end_with) and contain in net.lower()
+                ]
+                return nets_found
+            elif end_with and not start_with and not contain:
+                nets_found = [
+                    self.nets[net].net_object for net in list(self.nets.keys()) if net.lower().endswith(end_with)
+                ]
+                return nets_found
+            elif contain and not start_with and not end_with:
+                nets_found = [self.nets[net].net_object for net in list(self.nets.keys()) if contain in net.lower()]
+                return nets_found
 
     @pyaedt_function_handler()
     def is_net_in_component(self, component_name, net_name):
