@@ -7,11 +7,11 @@ import time
 import warnings
 
 from pyaedt.edb_core.EDB_Data import SimulationConfiguration
+from pyaedt.edb_core.EDB_Data import SourceType
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.generic.constants import SweepType
 from pyaedt.generic.general_methods import _retry_ntimes
 from pyaedt.generic.general_methods import generate_unique_name
-from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
 
@@ -431,20 +431,9 @@ class EdbSiwave(object):
         pos_pin = source.positive_node.node_pins
         neg_pin = source.negative_node.node_pins
 
-        if is_ironpython:
-            res, fromLayer_pos, toLayer_pos = pos_pin.GetLayerRange()
-            res, fromLayer_neg, toLayer_neg = neg_pin.GetLayerRange()
-        else:
-            (
-                res,
-                fromLayer_pos,
-                toLayer_pos,
-            ) = source.positive_node.node_pins.GetLayerRange(None, None)
-            (
-                res,
-                fromLayer_neg,
-                toLayer_neg,
-            ) = source.negative_node.node_pins.GetLayerRange(None, None)
+        res, fromLayer_pos, toLayer_pos = pos_pin.GetLayerRange()
+        res, fromLayer_neg, toLayer_neg = neg_pin.GetLayerRange()
+
         pos_pingroup_terminal = _retry_ntimes(
             10,
             self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,
@@ -1313,91 +1302,101 @@ class EdbSiwave(object):
             ``True`` when successful, ``False`` when failed.
         """
 
-        if not isinstance(simulation_setup, SimulationConfiguration):
+        if not isinstance(simulation_setup, SimulationConfiguration):  # pragma: no cover
             return False
-        simsetup_info = self._pedb.simsetupdata.SimSetupInfo[self._pedb.simsetupdata.SIwave.SIWSimulationSettings]()
-        simsetup_info.Name = simulation_setup.setup_name
-        simsetup_info.SimulationSettings.AdvancedSettings.PerformERC = False
-        simsetup_info.SimulationSettings.UseCustomSettings = True
-        if simulation_setup.include_inter_plane_coupling:
-            simsetup_info.SimulationSettings.AdvancedSettings.IncludeInterPlaneCoupling = (
-                simulation_setup.include_inter_plane_coupling
-            )
-        if abs(simulation_setup.xtalk_threshold):
-            simsetup_info.SimulationSettings.AdvancedSettings.XtalkThreshold = str(simulation_setup.xtalk_threshold)
-        if simulation_setup.min_void_area:
-            simsetup_info.SimulationSettings.AdvancedSettings.MinVoidArea = simulation_setup.min_void_area
-        if simulation_setup.min_pad_area_to_mesh:
-            simsetup_info.SimulationSettings.AdvancedSettings.MinPadAreaToMesh = simulation_setup.min_pad_area_to_mesh
-        if simulation_setup.min_plane_area_to_mesh:
-            simsetup_info.SimulationSettings.AdvancedSettings.MinPlaneAreaToMesh = (
-                simulation_setup.min_plane_area_to_mesh
-            )
-        if simulation_setup.snap_length_threshold:
-            simsetup_info.SimulationSettings.AdvancedSettings.SnapLengthThreshold = (
-                simulation_setup.snap_length_threshold
-            )
-        if simulation_setup.return_current_distribution:
-            simsetup_info.SimulationSettings.AdvancedSettings.ReturnCurrentDistribution = (
-                simulation_setup.return_current_distribution
-            )
-        if simulation_setup.ignore_non_functional_pads:
-            simsetup_info.SimulationSettings.AdvancedSettings.IgnoreNonFunctionalPads = (
-                simulation_setup.ignore_non_functional_pads
-            )
-        if simulation_setup.dc_min_plane_area_to_mesh:
-            simsetup_info.SimulationSettings.DCAdvancedSettings.DcMinPlaneAreaToMesh = (
-                simulation_setup.dc_min_plane_area_to_mesh
-            )
-        if simulation_setup.min_void_area:
-            simsetup_info.SimulationSettings.DCAdvancedSettings.DcMinVoidAreaToMesh = simulation_setup.min_void_area
-        if simulation_setup.max_init_mesh_edge_length:
-            simsetup_info.SimulationSettings.DCAdvancedSettings.MaxInitMeshEdgeLength = (
-                simulation_setup.max_init_mesh_edge_length
-            )
-        try:
-            sweep = self._pedb.simsetupdata.SweepData(simulation_setup.sweep_name)
-            sweep.IsDiscrete = False  # need True for package??
-            sweep.UseQ3DForDC = simulation_setup.use_q3d_for_dc
-            sweep.RelativeSError = simulation_setup.relative_error
-            sweep.InterpUsePortImpedance = False
-            sweep.EnforceCausality = (GeometryOperators.parse_dim_arg(simulation_setup.start_frequency) - 0) < 1e-9
-            sweep.EnforcePassivity = simulation_setup.enforce_passivity
-            sweep.PassivityTolerance = simulation_setup.passivity_tolerance
-            if is_ironpython:
-                sweep.Frequencies.Clear()
-            else:
-                list(sweep.Frequencies).clear()
-            if simulation_setup.sweep_type == SweepType.LogCount:
-                self._setup_decade_count_sweep(
-                    sweep,
-                    simulation_setup.start_frequency,
-                    simulation_setup.stop_freq,
-                    simulation_setup.decade_count,
+        if simulation_setup.solver_type == SolverType.SiwaveSYZ:  # pragma: no cover
+            simsetup_info = self._pedb.simsetupdata.SimSetupInfo[self._pedb.simsetupdata.SIwave.SIWSimulationSettings]()
+            simsetup_info.Name = simulation_setup.setup_name
+            simsetup_info.SimulationSettings.AdvancedSettings.PerformERC = False
+            simsetup_info.SimulationSettings.UseCustomSettings = True
+            if simulation_setup.include_inter_plane_coupling:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.IncludeInterPlaneCoupling = (
+                    simulation_setup.include_inter_plane_coupling
                 )
-            else:
-                if is_ironpython:
-                    sweep.Frequencies = self._pedb.simsetupdata.SweepData.SetFrequencies(
+            if abs(simulation_setup.xtalk_threshold):  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.XtalkThreshold = str(simulation_setup.xtalk_threshold)
+            if simulation_setup.min_void_area:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.MinVoidArea = simulation_setup.min_void_area
+            if simulation_setup.min_pad_area_to_mesh:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.MinPadAreaToMesh = (
+                    simulation_setup.min_pad_area_to_mesh
+                )
+            if simulation_setup.min_plane_area_to_mesh:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.MinPlaneAreaToMesh = (
+                    simulation_setup.min_plane_area_to_mesh
+                )
+            if simulation_setup.snap_length_threshold:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.SnapLengthThreshold = (
+                    simulation_setup.snap_length_threshold
+                )
+            if simulation_setup.return_current_distribution:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.ReturnCurrentDistribution = (
+                    simulation_setup.return_current_distribution
+                )
+            if simulation_setup.ignore_non_functional_pads:  # pragma: no cover
+                simsetup_info.SimulationSettings.AdvancedSettings.IgnoreNonFunctionalPads = (
+                    simulation_setup.ignore_non_functional_pads
+                )
+            if simulation_setup.dc_min_plane_area_to_mesh:  # pragma: no cover
+                simsetup_info.SimulationSettings.DCAdvancedSettings.DcMinPlaneAreaToMesh = (
+                    simulation_setup.dc_min_plane_area_to_mesh
+                )
+            if simulation_setup.min_void_area:  # pragma: no cover
+                simsetup_info.SimulationSettings.DCAdvancedSettings.DcMinVoidAreaToMesh = simulation_setup.min_void_area
+            if simulation_setup.max_init_mesh_edge_length:  # pragma: no cover
+                simsetup_info.SimulationSettings.DCAdvancedSettings.MaxInitMeshEdgeLength = (
+                    simulation_setup.max_init_mesh_edge_length
+                )
+            try:
+                sweep = self._pedb.simsetupdata.SweepData(simulation_setup.sweep_name)
+                sweep.IsDiscrete = False  # need True for package??
+                sweep.UseQ3DForDC = simulation_setup.use_q3d_for_dc
+                sweep.RelativeSError = simulation_setup.relative_error
+                sweep.InterpUsePortImpedance = False
+                sweep.EnforceCausality = (GeometryOperators.parse_dim_arg(simulation_setup.start_frequency) - 0) < 1e-9
+                sweep.EnforcePassivity = simulation_setup.enforce_passivity
+                sweep.PassivityTolerance = simulation_setup.passivity_tolerance
+                if is_ironpython:  # pragma: no cover
+                    sweep.Frequencies.Clear()
+                else:
+                    list(sweep.Frequencies).clear()
+                if simulation_setup.sweep_type == SweepType.LogCount:  # pragma: no cover
+                    self._setup_decade_count_sweep(
+                        sweep,
                         simulation_setup.start_frequency,
                         simulation_setup.stop_freq,
-                        simulation_setup.step_freq,
+                        simulation_setup.decade_count,
                     )
                 else:
-                    sweep.Frequencies = convert_py_list_to_net_list(
-                        self._pedb.simsetupdata.SweepData.SetFrequencies(
+                    if is_ironpython:
+                        sweep.Frequencies = self._pedb.simsetupdata.SweepData.SetFrequencies(
                             simulation_setup.start_frequency,
                             simulation_setup.stop_freq,
                             simulation_setup.step_freq,
                         )
-                    )
-            if is_ironpython:
-                simsetup_info.SweepDataList.Add(sweep)
-            else:
-                simsetup_info.SweepDataList = convert_py_list_to_net_list([sweep])
-        except Exception as err:
-            self._logger.error("Exception in sweep configuration: {0}".format(err))
-        sim_setup = self._edb.Utility.SIWaveSimulationSetup(simsetup_info)
-        return self._cell.AddSimulationSetup(sim_setup)
+                    else:
+                        sweep.Frequencies = convert_py_list_to_net_list(
+                            self._pedb.simsetupdata.SweepData.SetFrequencies(
+                                simulation_setup.start_frequency,
+                                simulation_setup.stop_freq,
+                                simulation_setup.step_freq,
+                            )
+                        )
+                if is_ironpython:
+                    simsetup_info.SweepDataList.Add(sweep)
+                else:
+                    simsetup_info.SweepDataList = convert_py_list_to_net_list([sweep])
+            except Exception as err:
+                self._logger.error("Exception in sweep configuration: {0}.".format(err))
+            sim_setup = self._edb.Utility.SIWaveSimulationSetup(simsetup_info)
+            return self._cell.AddSimulationSetup(sim_setup)
+        if simulation_setup.solver_type == SolverType.SiwaveDC:  # pragma: no cover
+            simsetup_info = self._pedb.simsetupdata.SimSetupInfo[
+                self._pedb.simsetupdata.SIwave.SIWDCIRSimulationSettings
+            ]()
+            simsetup_info.Name = simulation_setup.setup_name
+            sim_setup = self._edb.Utility.SIWaveDCIRSimulationSetup(simsetup_info)
+            return self._cell.AddSimulationSetup(sim_setup)
 
     def _setup_decade_count_sweep(self, sweep, start_freq, stop_freq, decade_count):
         import math
