@@ -5,22 +5,24 @@ This module contains the `EdbStackup` class.
 
 from __future__ import absolute_import  # noreorder
 
+import logging
 import math
-import os
+import difflib
 import warnings
 
 from pyaedt.edb_core.EDB_Data import EDBLayers
 from pyaedt.edb_core.general import convert_py_list_to_net_list
-from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.edb_core.EDB_Data import SimulationConfiguration
+from pyaedt.generic.general_methods import is_ironpython
+
 
 try:
     import clr
-    from System import Double
 except ImportError:
-    if os.name != "posix":
-        warnings.warn('This module requires the "pythonnet" package.')
+    warnings.warn("This module requires the PythonNET package.")
+
+logger = logging.getLogger(__name__)
 
 
 class EdbStackup(object):
@@ -65,11 +67,6 @@ class EdbStackup(object):
         """ """
         return self._pedb.db
 
-    @property
-    def _stackup_methods(self):
-        """ """
-        return self._pedb.edblib.Layout.StackupMethods
-
     @property
     def _logger(self):
         """ """
@@ -272,6 +269,20 @@ class EdbStackup(object):
         )
         return self._add_dielectric_material_model(name, material_def)
 
+    @pyaedt_function_handler()
+    def get_layout_thickness(self):
+        """Return the layout thickness.
+
+        Returns
+        --------
+        Float, the thickness value.
+        """
+        layers_name = list(self.stackup_layers.layers.keys())
+        bottom_layer = self.stackup_layers.layers[layers_name[0]]
+        top_layer = self.stackup_layers.layers[layers_name[-1]]
+        thickness = top_layer.lower_elevation + top_layer.thickness_value - bottom_layer.lower_elevation
+        return thickness
+
     @pyaedt_function_handler()
     def duplicate_material(self, material_name, new_material_name):
         """Duplicate a material from the database.
@@ -330,9 +341,43 @@ class EdbStackup(object):
             edb_material.SetProperty(self._edb.Definition.MaterialPropertyId.MagneticLossTangent, magnetic_loss_tangent)
             return edb_material
 
+    @pyaedt_function_handler
+    def material_name_to_id(self, property_name):
+        """Convert a material property name to a material property ID.
+
+        Parameters
+        ----------
+        property_name : str
+            Name of the material property.
+
+        Returns
+        -------
+        ID of the material property.
+        """
+        props = {
+            "Permittivity": self._edb.Definition.MaterialPropertyId.Permittivity,
+            "Permeability": self._edb.Definition.MaterialPropertyId.Permeability,
+            "Conductivity": self._edb.Definition.MaterialPropertyId.Conductivity,
+            "DielectricLossTangent": self._edb.Definition.MaterialPropertyId.DielectricLossTangent,
+            "MagneticLossTangent": self._edb.Definition.MaterialPropertyId.MagneticLossTangent,
+            "ThermalConductivity": self._edb.Definition.MaterialPropertyId.ThermalConductivity,
+            "MassDensity": self._edb.Definition.MaterialPropertyId.MassDensity,
+            "SpecificHeat": self._edb.Definition.MaterialPropertyId.SpecificHeat,
+            "YoungsModulus": self._edb.Definition.MaterialPropertyId.YoungsModulus,
+            "PoissonsRatio": self._edb.Definition.MaterialPropertyId.PoissonsRatio,
+            "ThermalExpansionCoefficient": self._edb.Definition.MaterialPropertyId.ThermalExpansionCoefficient,
+            "InvalidProperty": self._edb.Definition.MaterialPropertyId.InvalidProperty,
+        }
+
+        found_el = difflib.get_close_matches(property_name, list(props.keys()), 1, 0.7)
+        if found_el:
+            return props[found_el[0]]
+        else:
+            return self._edb.Definition.MaterialPropertyId.InvalidProperty
+
     @pyaedt_function_handler()
     def get_property_by_material_name(self, property_name, material_name):
-        """Get the property of a material. If it is executed in ironpython,
+        """Get the property of a material. If it is executed in IronPython,
          you must only use the first element of the returned tuple, which is a float.
 
         Parameters
@@ -368,52 +413,14 @@ class EdbStackup(object):
             original_material = self._edb.Definition.MaterialDef.FindByName(self._db, material_name)
             if is_ironpython:  # pragma: no cover
                 property_box = clr.StrongBox[float]()
-                if property_name == "permittivity":
-                    original_material.GetProperty(self._edb.Definition.MaterialPropertyId.Permittivity, property_box)
-                elif property_name == "permeability":
-                    original_material.GetProperty(self._edb.Definition.MaterialPropertyId.Permeability, property_box)
-                elif property_name == "conductivity":
-                    original_material.GetProperty(self._edb.Definition.MaterialPropertyId.Conductivity, property_box)
-                elif property_name == "dielectric_loss_tangent":
-                    original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.DielectricLossTangent, property_box
-                    )
-                elif property_name == "magnetic_loss_tangent":
-                    original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.MagneticLossTangent, property_box
-                    )
-                else:
-                    self._logger.error("Incorrect property name.")
-                    return False
-                property_float = float(property_box)
-                return property_float
+                original_material.GetProperty(self.material_name_to_id(property_name), property_box)
+                return float(property_box)
             else:
-                out_value = self._edb.Utility.Value("value_name")
-                if property_name == "permittivity":
-                    property_tuple = original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.Permittivity, out_value
-                    )
-                elif property_name == "permeability":
-                    property_tuple = original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.Permeability, out_value
-                    )
-                elif property_name == "conductivity":
-                    property_tuple = original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.Conductivity, out_value
-                    )
-                elif property_name == "dielectric_loss_tangent":
-                    property_tuple = original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.DielectricLossTangent, out_value
-                    )
-                elif property_name == "magnetic_loss_tangent":
-                    property_tuple = original_material.GetProperty(
-                        self._edb.Definition.MaterialPropertyId.MagneticLossTangent, out_value
-                    )
-                else:
-                    self._logger.error("Incorrect property name.")
-                    return False
-                property_float = float(property_tuple[1].ToDouble())
-                return property_float
+                _, property_box = original_material.GetProperty(
+                    self.material_name_to_id(property_name), self._get_edb_value(0.0)
+                )
+                return property_box.ToDouble()
+        return False
 
     @pyaedt_function_handler()
     def _get_solder_height(self, layer_name):
@@ -673,8 +680,8 @@ class EdbStackup(object):
             edb_cell.GetLayout(), self._active_layout.GetCell().GetName(), self._active_layout
         )
 
-        stackup_target = edb_cell.GetLayout().GetLayerCollection()
-        stackup_source = self._active_layout.GetLayerCollection()
+        stackup_target = self._edb.Cell.LayerCollection(edb_cell.GetLayout().GetLayerCollection())
+        stackup_source = self._edb.Cell.LayerCollection(self._active_layout.GetLayerCollection())
 
         if place_on_top:
             cell_inst2.SetPlacementLayer(list(stackup_target.Layers(self._edb.Cell.LayerTypeSet.SignalLayerSet))[0])
@@ -682,34 +689,13 @@ class EdbStackup(object):
             cell_inst2.SetPlacementLayer(list(stackup_target.Layers(self._edb.Cell.LayerTypeSet.SignalLayerSet))[-1])
         cell_inst2.SetIs3DPlacement(True)
         sig_set = self._edb.Cell.LayerTypeSet.SignalLayerSet
+        res = stackup_target.GetTopBottomStackupLayers(sig_set)
+        target_top_elevation = res[2]
+        target_bottom_elevation = res[4]
+        res_s = stackup_source.GetTopBottomStackupLayers(sig_set)
+        source_stack_top_elevation = res_s[2]
+        source_stack_bot_elevation = res_s[4]
 
-        if is_ironpython:  # pragma: no cover
-            res = stackup_target.GetTopBottomStackupLayers(sig_set)
-            target_top_elevation = res[2]
-            target_bottom_elevation = res[4]
-            res_s = stackup_source.GetTopBottomStackupLayers(sig_set)
-            source_stack_top_elevation = res_s[2]
-            source_stack_bot_elevation = res_s[4]
-        else:
-            target_top = None
-            target_top_elevation = Double(0.0)
-            target_bottom = None
-            target_bottom_elevation = Double(0.0)
-            source_stack_top = None
-            source_stack_top_elevation = Double(0.0)
-            source_stack_bot = None
-            source_stack_bot_elevation = Double(0.0)
-            res = stackup_target.GetTopBottomStackupLayers(
-                sig_set, target_top, target_top_elevation, target_bottom, target_bottom_elevation
-            )
-
-            res_s = stackup_source.GetTopBottomStackupLayers(
-                sig_set, source_stack_top, source_stack_top_elevation, source_stack_bot, source_stack_bot_elevation
-            )
-            target_top_elevation = res[2]
-            target_bottom_elevation = res[4]
-            source_stack_top_elevation = res_s[2]
-            source_stack_bot_elevation = res_s[4]
         if place_on_top and flipped_stackup:
             elevation = target_top_elevation + source_stack_top_elevation
         elif place_on_top:
@@ -734,6 +720,85 @@ class EdbStackup(object):
         cell_inst2.Set3DTransformation(point_loc, point_from, point_to, rotation, point3d_t)
         return True
 
+    @pyaedt_function_handler()
+    def place_a3dcomp_3d_placement(self, a3dcomp_path, angle=0.0, offset_x=0.0, offset_y=0.0, place_on_top=True):
+        """Place current Cell into another cell using 3d placement method.
+        Flip the current layer stackup of a layout if requested. Transform parameters currently not supported.
+
+        Parameters
+        ----------
+        a3dcomp_path : str
+            Path to 3D Component file (*.a3dcomp) to place.
+        angle : double, optional
+            Clockwise rotation angle applied to the a3dcomp.
+        offset_x : double, optional
+            The x offset value.
+        offset_y : double, optional
+            The y offset value.
+        place_on_top : bool, optional
+            Whether to place the 3D Component on the top or bottom of this layout.
+            If False then the 3D Component will also be flipped over around its X axis.
+
+        Returns
+        -------
+        bool
+            ``True`` if successful and ``False`` if not.
+
+        Examples
+        --------
+        >>> edb1 = Edb(edbpath=targetfile1,  edbversion="2021.2")
+        >>> a3dcomp_path = "connector.a3dcomp"
+        >>> edb1.core_stackup.place_a3dcomp_3d_placement(a3dcomp_path, angle=0.0, offset_x="1mm",
+        ...                                   offset_y="2mm", flipped_stackup=False, place_on_top=True,
+        ...                                   )
+        """
+        zero_data = self._get_edb_value(0.0)
+        one_data = self._get_edb_value(1.0)
+        local_origin = self._edb.Geometry.Point3DData(zero_data, zero_data, zero_data)
+        rotation_axis_from = self._edb.Geometry.Point3DData(one_data, zero_data, zero_data)
+        _angle = angle * math.pi / 180.0
+        rotation_axis_to = self._edb.Geometry.Point3DData(
+            self._get_edb_value(math.cos(_angle)), self._get_edb_value(-1 * math.sin(_angle)), zero_data
+        )
+
+        stackup_target = self._edb.Cell.LayerCollection(self._active_layout.GetLayerCollection())
+        sig_set = self._edb.Cell.LayerTypeSet.SignalLayerSet
+        res = stackup_target.GetTopBottomStackupLayers(sig_set)
+        target_top_elevation = res[2]
+        target_bottom_elevation = res[4]
+        flip_angle = self._get_edb_value("0deg")
+        if place_on_top:
+            elevation = target_top_elevation
+        else:
+            flip_angle = self._get_edb_value("180deg")
+            elevation = target_bottom_elevation
+        h_stackup = self._get_edb_value(elevation)
+        location = self._edb.Geometry.Point3DData(
+            self._get_edb_value(offset_x), self._get_edb_value(offset_y), h_stackup
+        )
+
+        mcad_model = self._edb.McadModel.Create3DComp(self._active_layout, a3dcomp_path)
+        if mcad_model.IsNull():  # pragma: no cover
+            logger.error("Failed to create MCAD model from a3dcomp")
+            return False
+
+        cell_instance = mcad_model.GetCellInstance()
+        if cell_instance.IsNull():  # pragma: no cover
+            logger.error("Cell instance of a3dcomp is null")
+            return False
+
+        if not cell_instance.SetIs3DPlacement(True):  # pragma: no cover
+            logger.error("Failed to set 3D placement on a3dcomp cell instance")
+            return False
+
+        if not cell_instance.Set3DTransformation(
+            local_origin, rotation_axis_from, rotation_axis_to, flip_angle, location
+        ):  # pragma: no cover
+            logger.error("Failed to set 3D transform on a3dcomp cell instance")
+            return False
+
+        return True
+
     @pyaedt_function_handler()
     def flip_design(self):
         """Flip the current design of a layout.
@@ -902,23 +967,13 @@ class EdbStackup(object):
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        stackup = self._active_layout.GetLayerCollection()
+        stackup = self._edb.Cell.LayerCollection(self._active_layout.GetLayerCollection())
         if only_metals:
             input_layers = self._edb.Cell.LayerTypeSet.SignalLayerSet
         else:
             input_layers = self._edb.Cell.LayerTypeSet.StackupLayerSet
 
-        if is_ironpython:
-            res, topl, topz, bottoml, bottomz = stackup.GetTopBottomStackupLayers(input_layers)
-        else:
-            topl = None
-            topz = Double(0.0)
-            bottoml = None
-            bottomz = Double(0.0)
-            res, topl, topz, bottoml, bottomz = stackup.GetTopBottomStackupLayers(
-                input_layers, topl, topz, bottoml, bottomz
-            )
-        h_stackup = abs(float(topz) - float(bottomz))
+        res, topl, topz, bottoml, bottomz = stackup.GetTopBottomStackupLayers(input_layers)
         return topl.GetName(), topz, bottoml.GetName(), bottomz
 
     def create_symmetric_stackup(
