@@ -18,36 +18,8 @@ from pyaedt.modules.Boundary import BoundaryObject, MaxwellParameters
 
 class Maxwell(object):
     def __init__(self):
-        self._odefinition_manager = self.materials.odefinition_manager
-        self._omaterial_manager = self.materials.omaterial_manager
-        self._o_maxwell_parameters = self.odesign.GetModule("MaxwellParameterSetup")
         pass
 
-    @property
-    def o_maxwell_parameters(self):
-        """AEDT Maxwel Parameter Setup Object.
-
-        References
-        ----------
-
-        >>> oDesign.GetModule("MaxwellParameterSetup")
-        """
-        return self._o_maxwell_parameters
-
-    @property
-    def omodelsetup(self):
-        """AEDT Model Setup Object.
-
-        References
-        ----------
-
-        >>> oDesign.GetModule("ModelSetup")
-        """
-        if self.solution_type != "Transient":
-            return None
-        else:
-            return self._odesign.GetModule("ModelSetup")
-
     @property
     def symmetry_multiplier(self):
         """Symmetry multiplier.
@@ -202,10 +174,10 @@ class Maxwell(object):
         Set matrix in a Maxwell analysis.
 
         >>> m2d = Maxwell2d(solution_type="MagnetostaticXY", close_on_exit=True, specified_version="2022.1")
-        >>> coil1 = m2d.modeler.primitives.create_rectangle([0, 1.5, 0], [8, 3], is_covered=True, name="Coil_1")
-        >>> coil2 = m2d.modeler.primitives.create_rectangle([8.5, 1.5, 0], [8, 3], is_covered=True, name="Coil_2")
-        >>> coil3 = m2d.modeler.primitives.create_rectangle([16, 1.5, 0], [8, 3], is_covered=True, name="Coil_3")
-        >>> coil4 = m2d.modeler.primitives.create_rectangle([32, 1.5, 0], [8, 3], is_covered=True, name="Coil_4")
+        >>> coil1 = m2d.modeler.create_rectangle([0, 1.5, 0], [8, 3], is_covered=True, name="Coil_1")
+        >>> coil2 = m2d.modeler.create_rectangle([8.5, 1.5, 0], [8, 3], is_covered=True, name="Coil_2")
+        >>> coil3 = m2d.modeler.create_rectangle([16, 1.5, 0], [8, 3], is_covered=True, name="Coil_3")
+        >>> coil4 = m2d.modeler.create_rectangle([32, 1.5, 0], [8, 3], is_covered=True, name="Coil_4")
         >>> current1 = m2d.assign_current("Coil_1", amplitude=1, swap_direction=False, name="Current1")
         >>> current2 = m2d.assign_current("Coil_2", amplitude=1, swap_direction=True, name="Current2")
         >>> current3 = m2d.assign_current("Coil_3", amplitude=1, swap_direction=True, name="Current3")
@@ -267,7 +239,7 @@ class Maxwell(object):
                 self.logger.info("Infinite is the only return path option in EddyCurrent")
                 return_path = ["infinite"] * len(sources)
 
-        if not self.solution_type in ["Transient", "ElectricTransient"]:
+        if self.solution_type not in ["Transient", "ElectricTransient"]:
             if not matrix_name:
                 matrix_name = generate_unique_name("Matrix")
             if not turns or len(sources) != len(self.modeler.convert_to_selections(turns, True)):
@@ -424,7 +396,7 @@ class Maxwell(object):
         activate_eddy_effects : bool, optional
             Whether to activate eddy effects. The default is ``True``.
         activate_displacement_current : bool, optional
-            Whether to activate eddy effects. The default is ``True``.
+            Whether to activate the displacement current. The default is ``True``.
 
         Returns
         -------
@@ -438,35 +410,57 @@ class Maxwell(object):
         """
         solid_objects_names = self.get_all_conductors_names()
 
-        if not activate_eddy_effects:
-            activate_displacement_current = False
-
         EddyVector = ["NAME:EddyEffectVector"]
-        for obj in solid_objects_names:
-            if obj in object_list:
-                EddyVector.append(
-                    [
-                        "NAME:Data",
-                        "Object Name:=",
-                        obj,
-                        "Eddy Effect:=",
-                        activate_eddy_effects,
-                        "Displacement Current:=",
-                        activate_displacement_current,
-                    ]
-                )
-            else:
-                EddyVector.append(
-                    [
-                        "NAME:Data",
-                        "Object Name:=",
-                        obj,
-                        "Eddy Effect:=",
-                        bool(self.oboundary.GetEddyEffect(obj)),
-                        "Displacement Current:=",
-                        bool(self.oboundary.GetDisplacementCurrent(obj)),
-                    ]
-                )
+        if self.modeler._is3d:
+            if not activate_eddy_effects:
+                activate_displacement_current = False
+            for obj in solid_objects_names:
+                if obj in object_list:
+                    EddyVector.append(
+                        [
+                            "NAME:Data",
+                            "Object Name:=",
+                            obj,
+                            "Eddy Effect:=",
+                            activate_eddy_effects,
+                            "Displacement Current:=",
+                            activate_displacement_current,
+                        ]
+                    )
+                else:
+                    EddyVector.append(
+                        [
+                            "NAME:Data",
+                            "Object Name:=",
+                            obj,
+                            "Eddy Effect:=",
+                            bool(self.oboundary.GetEddyEffect(obj)),
+                            "Displacement Current:=",
+                            bool(self.oboundary.GetDisplacementCurrent(obj)),
+                        ]
+                    )
+        else:
+            for obj in solid_objects_names:
+                if obj in object_list:
+                    EddyVector.append(
+                        [
+                            "NAME:Data",
+                            "Object Name:=",
+                            obj,
+                            "Eddy Effect:=",
+                            activate_eddy_effects,
+                        ]
+                    )
+                else:
+                    EddyVector.append(
+                        [
+                            "NAME:Data",
+                            "Object Name:=",
+                            obj,
+                            "Eddy Effect:=",
+                            bool(self.oboundary.GetEddyEffect(obj)),
+                        ]
+                    )
 
         self.oboundary.SetEddyEffect(["NAME:Eddy Effect Setting", EddyVector])
         return True
