@@ -55,6 +55,9 @@ class Mechanical(FieldAnalysis3D, object):
         Port number of which start the oDesktop communication on already existing server.
         This parameter is ignored in new server creation. It works only on 2022R2.
         Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+    aedt_process_id : int, optional
+        Only used when ``new_desktop_session = False``, specifies by process ID which instance
+        of Electronics Desktop to point PyAEDT at.
 
     Examples
     --------
@@ -101,6 +104,7 @@ class Mechanical(FieldAnalysis3D, object):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
 
         FieldAnalysis3D.__init__(
@@ -117,6 +121,7 @@ class Mechanical(FieldAnalysis3D, object):
             student_version,
             machine,
             port,
+            aedt_process_id,
         )
 
     def __enter__(self):
