@@ -17,7 +17,6 @@ class ModelerRMxprt(Modeler):
 
     def __init__(self, app):
         Modeler.__init__(self, app)
-        self._oeditor = self._odesign.SetActiveEditor("Machine")
 
     @property
     def oeditor(self):
@@ -27,7 +26,7 @@ class ModelerRMxprt(Modeler):
         ----------
 
         >>> oEditor = oDesign.SetActiveEditor("Machine")"""
-        return self._oeditor
+        return self._app.oeditor
 
 
 class Modeler2D(GeometryModeler, Primitives2D):
@@ -129,52 +128,67 @@ class Modeler2D(GeometryModeler, Primitives2D):
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        self.oeditor.CreateCircle(
-            [
-                "NAME:CircleParameters",
-                "IsCovered:=",
-                True,
-                "XCenter:=",
-                "0mm",
-                "YCenter:=",
-                "0mm",
-                "ZCenter:=",
-                "0mm",
-                "Radius:=",
-                radius,
-                "WhichAxis:=",
-                "Z",
-                "NumSegments:=",
-                "0",
-            ],
-            [
-                "NAME:Attributes",
-                "Name:=",
-                name + "_split",
-                "Flags:=",
-                "",
-                "Color:=",
-                "(132 132 193)",
-                "Transparency:=",
-                0,
-                "PartCoordinateSystem:=",
-                "Global",
-                "UDMId:=",
-                "",
-                "Materiaobjidue:=",
-                '"vacuum"',
-                "SolveInside:=",
-                True,
-            ],
-        )
 
+        cir = self.modeler.create_circle([0, 0, 0], 3, name=name + "_split", matname="vacuum")
         self.oeditor.Copy(["NAME:Selections", "Selections:=", name])
-
+        objects = [i for i in self.modeler.object_names]
         self.oeditor.Paste()
-        self.oeditor.Intersect(
-            ["NAME:Selections", "Selections:=", "{0}1,{0}_split".format(name)],
-            ["NAME:IntersectParameters", "KeepOriginals:=", False],
-        )
-
-        self.subtract(name, name + "1")
+        name1 = [i for i in self.modeler.object_names if i not in objects]
+        self.intersect([name1[0], cir.name], keeporiginal=False)
+        self.subtract(name, name1[0])
         return True
+
+    @pyaedt_function_handler()
+    def objects_in_bounding_box(self, bounding_box, check_lines=True, check_sheets=True):
+        """Given a 2D bounding box, check if sheets and lines are inside it.
+
+        Parameters
+        ----------
+        bounding_box : list.
+            List of either the 4 or 6 coordinates of the bounding box vertices.
+        check_lines : bool, optional.
+            Whether to check line objects. The default is ``True``.
+        check_sheets : bool, optional.
+            Whether to check sheet objects. The default is ``True``.
+
+        Returns
+        -------
+        list of :class:`pyaedt.modeler.Object3d`
+        """
+
+        if len(bounding_box) != 4 and len(bounding_box) != 6:
+            raise ValueError("Bounding box must be a list of 4 or 6 elements.")
+
+        if len(bounding_box) == 4:
+            if self._app.design_type == "2D Extractor" or self._app.xy_plane:
+                bounding_box = [bounding_box[0], bounding_box[1], 0, bounding_box[2], bounding_box[3], 0]
+            else:
+                bounding_box = [bounding_box[0], 0, bounding_box[1], bounding_box[2], 0, bounding_box[3]]
+
+        objects_2d = []
+
+        if check_lines:
+            for obj in self._primitives.line_objects:
+                if (
+                    bounding_box[3] <= obj.bounding_box[0] <= bounding_box[0]
+                    and bounding_box[4] <= obj.bounding_box[1] <= bounding_box[1]
+                    and bounding_box[5] <= obj.bounding_box[2] <= bounding_box[2]
+                    and bounding_box[3] <= obj.bounding_box[3] <= bounding_box[0]
+                    and bounding_box[4] <= obj.bounding_box[4] <= bounding_box[1]
+                    and bounding_box[5] <= obj.bounding_box[5] <= bounding_box[2]
+                ):
+                    objects_2d.append(obj)
+
+        if check_sheets:
+            for obj in self._primitives.sheet_objects:
+                if (
+                    bounding_box[3] <= obj.bounding_box[0] <= bounding_box[0]
+                    and bounding_box[4] <= obj.bounding_box[1] <= bounding_box[1]
+                    and bounding_box[5] <= obj.bounding_box[2] <= bounding_box[2]
+                    and bounding_box[3] <= obj.bounding_box[3] <= bounding_box[0]
+                    and bounding_box[4] <= obj.bounding_box[4] <= bounding_box[1]
+                    and bounding_box[5] <= obj.bounding_box[5] <= bounding_box[2]
+                ):
+                    objects_2d.append(obj)
+
+        return objects_2d
