@@ -1,8 +1,23 @@
+import os
 from collections import OrderedDict
 
+from pyaedt import is_ironpython
+
+if not is_ironpython:
+    try:
+        import joblib
+    except ImportError:
+        pass
+    try:
+        import numpy as np
+    except ImportError:
+        pass
+
+from pyaedt import constants
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modules.MaterialLib import Material
+from pyaedt.generic.general_methods import is_ironpython
 
 LAYERS = {"s": "signal", "g": "ground", "d": "dielectric"}
 
@@ -22,8 +37,6 @@ def _replace_by_underscore(character, string):
 class NamedVariable(object):
     """Cast PyAEDT variable object to simplify getters and setters in Stackup3D.
 
-    The returned Polyline object exposes the methods for manipulating the polyline.
-
     Parameters
     ----------
     application : :class:`pyaedt.hfss.Hfss
@@ -103,9 +116,9 @@ class NamedVariable(object):
         return self._variable.numeric_value
 
     @property
-    def string_value(self):
+    def evaluated_value(self):
         """String that combines the numeric value and the units."""
-        return self._variable.string_value
+        return self._variable.evaluated_value
 
     @pyaedt_function_handler()
     def hide_variable(self, value=True):
@@ -173,7 +186,7 @@ class Layer3D(object):
         if thickness:
             self._thickness = NamedVariable(self._app, self._thickness_variable, str(thickness) + "mm")
         if self._layer_type == "dielectric":
-            obj_3d = self._app.modeler.primitives.create_box(
+            obj_3d = self._app.modeler.create_box(
                 ["dielectric_x_position", "dielectric_y_position", layer_position],
                 ["dielectric_length", "dielectric_width", self._thickness_variable],
                 name=self._name,
@@ -181,7 +194,7 @@ class Layer3D(object):
             )
         elif self._layer_type == "ground":
             if thickness:
-                obj_3d = self._app.modeler.primitives.create_box(
+                obj_3d = self._app.modeler.create_box(
                     ["dielectric_x_position", "dielectric_y_position", layer_position],
                     ["dielectric_length", "dielectric_width", self._thickness_variable],
                     name=self._name,
@@ -189,7 +202,7 @@ class Layer3D(object):
                 )
 
             else:
-                obj_3d = self._app.modeler.primitives.create_rectangle(
+                obj_3d = self._app.modeler.create_rectangle(
                     "Z",
                     ["dielectric_x_position", "dielectric_y_position", layer_position],
                     ["dielectric_length", "dielectric_width"],
@@ -198,14 +211,14 @@ class Layer3D(object):
                 )
         elif self._layer_type == "signal":
             if thickness:
-                obj_3d = self._app.modeler.primitives.create_box(
+                obj_3d = self._app.modeler.create_box(
                     ["dielectric_x_position", "dielectric_y_position", layer_position],
                     ["dielectric_length", "dielectric_width", self._thickness_variable],
                     name=self._name,
                     matname=self._fill_material,
                 )
             else:
-                obj_3d = self._app.modeler.primitives.create_rectangle(
+                obj_3d = self._app.modeler.create_rectangle(
                     "Z",
                     ["dielectric_x_position", "dielectric_y_position", layer_position],
                     ["dielectric_length", "dielectric_width"],
@@ -452,6 +465,66 @@ class Layer3D(object):
         created_patch.aedt_object.group_name = "Layer_{}".format(self._name)
         return created_patch
 
+    @pyaedt_function_handler()
+    def ml_patch(
+        self,
+        frequency,
+        patch_width,
+        patch_position_x=0,
+        patch_position_y=0,
+        patch_name=None,
+        axis="X",
+    ):
+        """Create a new parametric patch using machine learning algorithm rather than analytic formulas.
+
+        Parameters
+        ----------
+        frequency : float
+            Frequency value for patch calculation in Hz.
+        patch_width : float
+            Patch width.
+        patch_length : float
+            Patch Length.
+        patch_position_x : float, optional
+            Patch start x position.
+        patch_position_y : float, optional
+            Patch start y position.
+        patch_name : str, optional
+            Patch name.
+        axis : str, optional
+            Line orientation axis.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.stackup_3d.Patch`
+        """
+        if not patch_name:
+            patch_name = generate_unique_name("{}_patch".format(self._name), n=3)
+        lst = self._stackup._layer_name
+        for i in range(len(lst)):
+            if lst[i] == self._name:
+                if self._stackup.stackup_layers[lst[i - 1]]._layer_type == "dielectric":
+                    below_layer = self._stackup.stackup_layers[lst[i - 1]]
+                    break
+                else:
+                    self._app.logger.error("The layer below the selected one must be of dielectric type")
+                    return False
+        created_patch = MachineLearningPatch(
+            self._app,
+            frequency,
+            patch_width,
+            signal_layer=self,
+            dielectric_layer=below_layer,
+            patch_position_x=patch_position_x,
+            patch_position_y=patch_position_y,
+            patch_name=patch_name,
+            axis=axis,
+        )
+        self._obj_3d.append(created_patch.aedt_object)
+        self._stackup._object_list.append(created_patch)
+        created_patch.aedt_object.group_name = "Layer_{}".format(self._name)
+        return created_patch
+
     @pyaedt_function_handler()
     def add_trace(
         self,
@@ -466,7 +539,7 @@ class Layer3D(object):
         reference_system=None,
         frequency=1e9,
     ):
-        """Create a line.
+        """Create a trace.
 
         Parameters
         ----------
@@ -585,12 +658,13 @@ class Layer3D(object):
 
 
 class PadstackLayer(object):
-    """Provides a Data class for the definition of a padstack layer and relative pad and antipad values."""
+    """Provides a data class for the definition of a padstack layer and relative pad and antipad values."""
 
-    def __init__(self, padstack, layer_name, elevation):
+    def __init__(self, padstack, layer_name, elevation, thickness):
         self._padstack = padstack
         self._layer_name = layer_name
         self._layer_elevation = elevation
+        self._layer_thickness = thickness
         self._pad_radius = 1
         self._antipad_radius = 2
         self._units = "mm"
@@ -609,10 +683,10 @@ class Padstack(object):
         self._plating_ratio = 1
         v = None
         k = None
-        for v in list(self._stackup.stackup_layers.values()):
+        for k, v in self._stackup.stackup_layers.items():
             if not self._padstacks_by_layer and v._layer_type == "dielectric":
                 continue
-            self._padstacks_by_layer[k] = PadstackLayer(self, k, v.elevation)
+            self._padstacks_by_layer[k] = PadstackLayer(self, k, v.elevation, v.thickness)
         if v and v._layer_type == "dielectric":
             del self._padstacks_by_layer[k]
         self._padstacks_material = material
@@ -781,9 +855,9 @@ class Padstack(object):
                     cyls.append(
                         self._app.modeler.create_cylinder(
                             "Z",
-                            [position_x, position_y, first_el.name],
+                            [position_x, position_y, v._layer_elevation.name],
                             v._pad_radius,
-                            v._layer_elevation.name,
+                            v._layer_thickness.name,
                             matname=self._padstacks_material,
                             name=instance_name,
                             numSides=self._num_sides,
@@ -792,9 +866,9 @@ class Padstack(object):
                     if self.plating_ratio < 1:
                         hole = self._app.modeler.create_cylinder(
                             "Z",
-                            [position_x, position_y, first_el.name],
+                            [position_x, position_y, v._layer_elevation.name],
                             "{}*{}".format(self._app.modeler._arg_with_dim(v._pad_radius), 1 - self.plating_ratio),
-                            v._layer_elevation.name,
+                            v._layer_thickness.name,
                             matname=self._padstacks_material,
                             name=instance_name,
                             numSides=self._num_sides,
@@ -802,9 +876,9 @@ class Padstack(object):
                         cyls[-1].subtract(hole, False)
                     anti = self._app.modeler.create_cylinder(
                         "Z",
-                        [position_x, position_y, first_el.name],
+                        [position_x, position_y, v._layer_elevation.name],
                         v._antipad_radius,
-                        v._layer_elevation.name,
+                        v._layer_thickness.name,
                         matname="air",
                         name=instance_name + "_antipad",
                     )
@@ -1122,6 +1196,12 @@ class Stackup3D(object):
         ----------
         name : str
             Layer name.
+        material : str
+            Material name. Material will be parametrized.
+        thickness : float
+            Thickness value. Thickness will be parametrized.
+        fill_material : str
+            Fill Material name. Material will be parametrized.=
         material : str, optional
             Material name. Material will be parametrized. Default value is `"copper"`.
         thickness : float, optional
@@ -1236,14 +1316,14 @@ class Stackup3D(object):
             list_of_2d_points = points_list_by_object + list_of_2d_points
         for via in self._vias:
             for v in via._vias_objects:
-                list_of_x_coordinates.append(v.bounding_box[0])
-                list_of_x_coordinates.append(v.bounding_box[2])
-                list_of_y_coordinates.append(v.bounding_box[1])
-                list_of_y_coordinates.append(v.bounding_box[3])
-                list_of_x_coordinates.append(v.bounding_box[0])
-                list_of_x_coordinates.append(v.bounding_box[2])
-                list_of_y_coordinates.append(v.bounding_box[3])
-                list_of_y_coordinates.append(v.bounding_box[1])
+                list_of_x_coordinates.append(v.bounding_box[0] - v.bounding_dimension[0])
+                list_of_x_coordinates.append(v.bounding_box[3] - v.bounding_dimension[0])
+                list_of_y_coordinates.append(v.bounding_box[1] - v.bounding_dimension[1])
+                list_of_y_coordinates.append(v.bounding_box[4] - v.bounding_dimension[1])
+                list_of_x_coordinates.append(v.bounding_box[0] + v.bounding_dimension[0])
+                list_of_x_coordinates.append(v.bounding_box[4] + v.bounding_dimension[0])
+                list_of_y_coordinates.append(v.bounding_box[4] + v.bounding_dimension[1])
+                list_of_y_coordinates.append(v.bounding_box[1] + v.bounding_dimension[1])
         for point in list_of_2d_points:
             list_of_x_coordinates.append(point[0])
             list_of_y_coordinates.append(point[1])
@@ -1251,12 +1331,36 @@ class Stackup3D(object):
         minimum_x = min(list_of_x_coordinates)
         maximum_y = max(list_of_y_coordinates)
         minimum_y = min(list_of_y_coordinates)
-        variation_x = maximum_x - minimum_x
-        variation_y = maximum_y - minimum_y
-        self._app["dielectric_x_position"] = str(minimum_x - variation_x / 2 * percentage_offset / 100) + "mm"
-        self._app["dielectric_y_position"] = str(minimum_y - variation_y / 2 * percentage_offset / 100) + "mm"
-        self._app["dielectric_length"] = str(maximum_x + variation_x * percentage_offset / 100) + "mm"
-        self._app["dielectric_width"] = str(maximum_y + variation_y * percentage_offset / 100) + "mm"
+        variation_x = abs(maximum_x - minimum_x)
+        variation_y = abs(maximum_y - minimum_y)
+        self._app["dielectric_x_position"] = str(minimum_x - variation_x * percentage_offset / 100) + "mm"
+        self._app["dielectric_y_position"] = str(minimum_y - variation_y * percentage_offset / 100) + "mm"
+        self._app["dielectric_length"] = str(maximum_x - minimum_x + 2 * variation_x * percentage_offset / 100) + "mm"
+        self._app["dielectric_width"] = str(maximum_y - minimum_y + 2 * variation_y * percentage_offset / 100) + "mm"
+        return True
+
+    def resize_around_element(self, element, percentage_offset=0.25):
+        """Resize the stackup around objects and make it parametrize.
+
+        Parameters
+        ----------
+        element : :class:`pyaedt.modeler.stackup_3d.Patch
+            Element around which the resizing is done.
+        percentage_offset : float, optional
+            Offset of resize. Value accepted are greater than 0. O.25 by default.
+
+        Returns
+        -------
+        bool
+        """
+        self._app["dielectric_x_position"] = (
+            element.position_x.name + " - " + element.length.name + " * " + str(percentage_offset)
+        )
+        self._app["dielectric_y_position"] = (
+            element.position_y.name + " - " + element.width.name + " * (0.5 + " + str(percentage_offset) + ")"
+        )
+        self._app["dielectric_length"] = element.length.name + " * (1 + " + str(percentage_offset) + " * 2)"
+        self._app["dielectric_width"] = element.width.name + " * (1 + " + str(percentage_offset) + " * 2)"
         return True
 
 
@@ -1468,7 +1572,7 @@ class Patch(CommonObject, object):
 
             self._reference_system = patch_name + "_CS"
         if signal_layer.thickness:
-            self._aedt_object = application.modeler.primitives.create_box(
+            self._aedt_object = application.modeler.create_box(
                 position=start_point,
                 dimensions_list=[
                     "{}_length".format(patch_name),
@@ -1479,7 +1583,7 @@ class Patch(CommonObject, object):
                 matname=signal_layer.material_name,
             )
         else:
-            self._aedt_object = application.modeler.primitives.create_rectangle(
+            self._aedt_object = application.modeler.create_rectangle(
                 position=start_point,
                 dimension_list=[self.length.name, self.width.name],
                 name=patch_name,
@@ -1647,7 +1751,7 @@ class Patch(CommonObject, object):
         # "c0 * 1000/(patch_frequency * sqrt(patch_eff_permittivity))"
         f = self._frequency.name
         er_e = self._effective_permittivity.name
-        patch_wave_length_formula = "c0 * 1000/(" + f + "* sqrt(" + er_e + "))"
+        patch_wave_length_formula = "(c0 * 1000/(" + f + "* sqrt(" + er_e + ")))mm"
         self._wave_length = NamedVariable(
             self.application,
             self._name + "_wave_length",
@@ -1721,6 +1825,56 @@ class Patch(CommonObject, object):
         )
         return self._impedance_l_w, self._impedance_w_l
 
+    def create_lumped_port(self, reference_layer, opposite_side=False, port_name=None, axisdir=None):
+        """Create a parametrized lumped port.
+
+        Parameters
+        ----------
+
+        reference_layer : class:`pyaedt.modeler.stackup_3d.Layer3D
+            The reference layer, in most cases the ground layer.
+        opposite_side : bool, optional
+            Change the side where the port is created.
+        port_name : str, optional
+            Name of the lumped port.
+        axisdir : int or :class:`pyaedt.application.Analysis.Analysis.AxisDir`, optional
+            Position of the port. It should be one of the values for ``Application.AxisDir``,
+            which are: ``XNeg``, ``YNeg``, ``ZNeg``, ``XPos``, ``YPos``, and ``ZPos``.
+            The default is ``Application.AxisDir.XNeg``.
+        Returns
+        -------
+        bool
+        """
+        string_position_x = self.position_x.name
+        if opposite_side:
+            string_position_x = self.position_x.name + " + " + self.length.name
+        string_position_y = self.position_y.name + " - " + self.width.name + "/2"
+        string_position_z = reference_layer.elevation.name
+        string_width = self.width.name
+        string_length = (
+            self._signal_layer.elevation.name
+            + " + "
+            + self._signal_layer.thickness.name
+            + " - "
+            + reference_layer.elevation.name
+        )
+        port = self.application.modeler.create_rectangle(
+            csPlane=constants.PLANE.YZ,
+            position=[string_position_x, string_position_y, string_position_z],
+            dimension_list=[string_width, string_length],
+            name=self.name + "_port",
+            matname=None,
+        )
+        if self.application.solution_type == "Modal":
+            if axisdir is None:
+                axisdir = self.application.AxisDir.ZPos
+            port = self.application.create_lumped_port_to_sheet(port.name, portname=port_name, axisdir=axisdir)
+        elif self.application.solution_type == "Terminal":
+            port = self.application.create_lumped_port_to_sheet(
+                port.name, portname=port_name, reference_object_list=[reference_layer.name]
+            )
+        return port
+
 
 class Trace(CommonObject, object):
     """Provides a class to create a trace in stackup."""
@@ -1845,7 +1999,7 @@ class Trace(CommonObject, object):
                 start_point = ["-{0}_width/2".format(self._name), 0, 0]
             self._reference_system = line_name + "_CS"
         if signal_layer.thickness:
-            self._aedt_object = application.modeler.primitives.create_box(
+            self._aedt_object = application.modeler.create_box(
                 position=start_point,
                 dimensions_list=[
                     "{}_length".format(self._name),
@@ -1856,7 +2010,7 @@ class Trace(CommonObject, object):
                 matname=signal_layer.material_name,
             )
         else:
-            self._aedt_object = application.modeler.primitives.create_rectangle(
+            self._aedt_object = application.modeler.create_rectangle(
                 position=start_point,
                 dimension_list=["{}_length".format(self._name), "{}_width".format(self._name)],
                 name=line_name,
@@ -2171,7 +2325,7 @@ class Trace(CommonObject, object):
         # TODO it is currently only available for mm
         f = self._frequency.name
         er_e = self._effective_permittivity.name
-        patch_wave_length_formula = "c0 * 1000/(" + f + "* sqrt(" + er_e + "))"
+        patch_wave_length_formula = "(c0 * 1000/(" + f + "* sqrt(" + er_e + ")))mm"
         self._wave_length = NamedVariable(
             self.application,
             self._name + "_wave_length",
@@ -2232,9 +2386,30 @@ class Trace(CommonObject, object):
                 axisdir = self.application.AxisDir.YNeg
             else:
                 axisdir = self.application.AxisDir.YPos
-        return self.application.create_lumped_port_between_objects(
+        p1 = self.application.create_lumped_port_between_objects(
             reference_layer_name, self.aedt_object.name, axisdir=axisdir
         )
+        z_elev = ""
+        start_count = False
+        for k, v in self._signal_layer._stackup.stackup_layers.items():
+            if k == reference_layer_name or k == self._signal_layer.name:
+                if not start_count:
+                    start_count = True
+                else:
+                    start_count = False
+            elif start_count:
+                z_elev += "-" + v.thickness.name
+        self.application.modeler.oeditor.ChangeProperty(
+            [
+                "NAME:AllTabs",
+                [
+                    "NAME:Geometry3DCmdTab",
+                    ["NAME:PropServers", self._name + ":Move:1"],
+                    ["NAME:ChangedProps", ["NAME:Move Vector", "X:=", "0mm", "Y:=", "0mm", "Z:=", z_elev]],
+                ],
+            ]
+        )
+        return p1
 
 
 class Polygon(CommonObject, object):
@@ -2296,3 +2471,57 @@ class Polygon(CommonObject, object):
         """
         bb = self._aedt_object.bounding_box
         return [[bb[0], bb[1]], [bb[0], bb[4]], [bb[3], bb[4]], [bb[3], bb[1]]]
+
+
+class MachineLearningPatch(Patch, object):
+    """MachineLearningPatch Class in Stackup3D."""
+
+    def __init__(
+        self,
+        application,
+        frequency,
+        patch_width,
+        signal_layer,
+        dielectric_layer,
+        patch_position_x=0,
+        patch_position_y=0,
+        patch_name="patch",
+        reference_system=None,
+        axis="X",
+    ):
+        Patch.__init__(
+            self,
+            application,
+            frequency,
+            patch_width,
+            signal_layer,
+            dielectric_layer,
+            patch_length=None,
+            patch_position_x=patch_position_x,
+            patch_position_y=patch_position_y,
+            patch_name=patch_name,
+            reference_system=reference_system,
+            axis=axis,
+        )
+        if not is_ironpython:
+            try:
+                joblib
+            except NameError:  # pragma: no cover
+                raise ImportError("joblib package is needed to run ML.")
+            path_file = os.path.dirname(__file__)
+            path_folder = os.path.split(path_file)[0]
+            training_file = os.path.join(path_folder, "misc", "patch_svr_model_100MHz_1GHz.joblib")
+            model = joblib.load(training_file)
+            list_for_array = [
+                [
+                    self.frequency.numeric_value,
+                    self.width.numeric_value,
+                    self._permittivity.numeric_value,
+                    self.dielectric_layer.thickness.numeric_value,
+                ]
+            ]
+            array_for_prediction = np.array(list_for_array, dtype=np.float32)
+            length = model.predict(array_for_prediction)[0]
+            self.length.expression = application.modeler._arg_with_dim(length)
+        else:  # pragma: no cover
+            self.application.logger.warning("Machine learning algorithm aren't covered in IronPython.")
