@@ -4,6 +4,7 @@ from collections import OrderedDict
 from pyaedt.generic.DataHandlers import _arg2dict
 from pyaedt.generic.DataHandlers import _dict2arg
 from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import PropsManager
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modules.OptimetricsTemplates import defaultdoeSetup
 from pyaedt.modules.OptimetricsTemplates import defaultdxSetup
@@ -14,7 +15,7 @@ from pyaedt.modules.OptimetricsTemplates import defaultstatisticalSetup
 from pyaedt.modules.SetupTemplates import SetupProps
 
 
-class CommonOptimetrics(object):
+class CommonOptimetrics(PropsManager, object):
     """Creates and sets up optimizations.
 
     Parameters
