@@ -13,6 +13,7 @@ from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import MethodNotSupportedError
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.generic.LoadAEDTFile import load_entire_aedt_file
+from pyaedt.generic.general_methods import PropsManager
 
 meshers = {
     "HFSS": "MeshSetup",
@@ -52,7 +53,7 @@ class MeshProps(OrderedDict):
         OrderedDict.__setitem__(self, key, value)
 
 
-class MeshOperation(object):
+class MeshOperation(PropsManager, object):
     """MeshOperation class.
 
     Parameters
@@ -204,9 +205,7 @@ class Mesh(object):
 
         self._odesign = self._app.odesign
         self.modeler = self._app.modeler
-        design_type = self._odesign.GetDesignType()
         self.logger = self._app.logger
-        self._omeshmodule = self._odesign.GetModule(meshers[design_type])
         self.id = 0
         self.meshoperations = self._get_design_mesh_operations()
         self._globalmesh = None
@@ -239,7 +238,7 @@ class Mesh(object):
 
         >>> oDesign.GetModule("MeshSetup")
         """
-        return self._omeshmodule
+        return self._app.omeshmodule
 
     @pyaedt_function_handler()
     def _get_design_global_mesh(self):
