@@ -11,10 +11,11 @@ from collections import OrderedDict
 from pyaedt.generic.DataHandlers import _dict2arg
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.generic.general_methods import PropsManager
 from pyaedt.modules.Mesh import MeshProps
 
 
-class Mesh3DOperation(object):
+class Mesh3DOperation(PropsManager, object):
     """Mesh3DOperation class.
 
     Parameters
@@ -132,7 +133,6 @@ class Mesh3d(object):
         self.logger = self._app.logger
         self._odesign = self._app._odesign
         self.modeler = self._app._modeler
-        self._omeshmodule = self._odesign.GetModule("SolveSetups")
         self.id = 0
 
         self.meshoperations = self._get_design_mesh_operations()
@@ -148,7 +148,7 @@ class Mesh3d(object):
 
         >>> oDesign.GetModule("SolveSetups")
         """
-        return self._omeshmodule
+        return self._app.omeshmodule
 
     @pyaedt_function_handler()
     def delete_mesh_operations(self, setup_name, mesh_name):
